#include "ifunc.h"
#ifdef USEHPL

#include "constants.h"
#include "fcomplex.h"
#include "gaussrules.h"

#include <ginac/ginac.h>
#include <math.h>
#include "clock_real.h"

using namespace std;
using namespace constants;
//using namespace GiNaC::H;
//using namespace GiNaC::ex_to;
//using namespace GiNaC::numeric;

double ifunc::i3qqp;
double ifunc::i3qqbp;
double ifunc::i3qq;
double ifunc::i3qqb;
double ifunc::i3qg;

//enum alphabet {neg=-1, zero=0, pos=1};

typedef int alphabet;

map <alphabet, map <alphabet, map <alphabet, map <alphabet, map <alphabet ,double> >>>> h5;

//relations from https://arxiv.org/pdf/hep-ph/9905237.pdf
//Eq.(1)
//h(0,z) = log(z)
//h(1,z) = -log(1-z)
//h(-1,z) = log(1+z)

double h1(int n, double z)
{
  if (n == 0) return log(z);
  if (n == 1) return -log(1-z);
  if (n == -1) return log(1+z);

  cout << "Error in h1 " << endl;
  exit(-1);
  return 0;
}


//Eq.(11)
//h(0,0,z) = 1./2. * pow(log(z),2)
//h(0,1,z) = Li2(z);
//h(0,-1,z) = -Li2(-z);

//Chaplin interface
extern "C"
{
  fcomplex hpl1_(int &n1,fcomplex &x);
  fcomplex hpl2_(int &n1,int &n2,fcomplex &x);
  fcomplex hpl3_(int &n1,int &n2,int &n3,fcomplex &x);
  fcomplex hpl4_(int &n1,int &n2,int &n3,int &n4,fcomplex &x);
}

//interface to polylogarithms
double h(vector <int> n, double z)
{
  //convert from compact to extended notation (expression with only -1,0,1)
  vector <int> m;

  for (vector<int>::iterator i = n.begin(); i != n.end(); i++)
    //for (unsigned int i = 0; i < n.size(); i++)
    {
      //if (n[i] > 1)
      if (*i > 1)
	{
	  //for (int j = 1; j < abs(n[i]); j++)
	  for (int j = 1; j < abs(*i); j++)
	    m.push_back(0);
	  m.push_back(1);
	}
      //else if (n[i] < -1)
      else if (*i < -1)
	{
	  //for (int j = 1; j < abs(n[i]); j++)
	  for (int j = 1; j < abs(*i); j++)
	    m.push_back(0);
	  m.push_back(-1);
	}
      else
	//m.push_back(n[i]);
	m.push_back(*i);
    }

  fcomplex x = fcx(z);

  //cout << m.size() << endl;
  //if (m.size() == 5)
  //{
  //cout << m[0]+1 << m[1]+1 << m[2]+1 << m[3]+1 << m[4]+1 << endl;
  //cout << "(";
  //std::copy(m.begin(), m.end(), std::ostream_iterator<int>(std::cout, ","));
  //cout << ")" << endl;;
  //}
  
  if (m.size() == 1)
    //return h1(m[0],z);
    return real(cx(hpl1_(m[0],x)));

  else if (m.size() == 2)
    return real(cx(hpl2_(m[0],m[1],x)));

  else if (m.size() == 3)
    return real(cx(hpl3_(m[0],m[1],m[2],x)));

  else if (m.size() == 4)
    return real(cx(hpl4_(m[0],m[1],m[2],m[3],x)));

  //Ginac  
  else
    {
      if (h5[m[0]][m[1]][m[2]][m[3]].find(m[4]) != h5[m[0]][m[1]][m[2]][m[3]].end())
	return h5[m[0]][m[1]][m[2]][m[3]][m[4]];
      else
	{
	  GiNaC::lst l = {};
	  for (unsigned int i = 0; i < m.size(); i++)
	    l.append(m[i]);
	  
	  h5[m[0]][m[1]][m[2]][m[3]][m[4]] = GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(l,z).eval())).to_double();
	  return h5[m[0]][m[1]][m[2]][m[3]][m[4]];
	}
	
      //clock_t begin_time, end_time;
      //begin_time = clock();
      GiNaC::lst l = {};
      for (unsigned int i = 0; i < m.size(); i++)
	l.append(m[i]);
      
      //return
      
      double hh = GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(l,z).eval())).to_double();
      //end_time = clock();
      //cout << "z = " << z << " H evaluated in "  << float(end_time - begin_time)/CLOCKS_PER_SEC*1000 << " ms" << endl;
      return hh;
    }

  cout << "Error in h " << endl;
  cout << n.size() << endl;
  cout << m.size() << endl;
  exit(-1);
  return 0;
}

double h(int n1, double z)
{
  vector <int> n;
  n.push_back(n1);
  return h(n,z);
}
double h(int n1, int n2, double z)
{
  vector <int> n;
  n.push_back(n1); n.push_back(n2);
  return h(n,z);
}
double h(int n1, int n2, int n3, double z)
{
  vector <int> n;
  n.push_back(n1); n.push_back(n2); n.push_back(n3);
  return h(n,z);
}
double h(int n1, int n2, int n3, int n4, double z)
{
  vector <int> n;
  n.push_back(n1); n.push_back(n2); n.push_back(n3); n.push_back(n4);
  return h(n,z);
}
double h(int n1, int n2, int n3, int n4, int n5, double z)
{
  vector <int> n;
  n.push_back(n1); n.push_back(n2); n.push_back(n3); n.push_back(n4); n.push_back(n5);
  return h(n,z);
}

void ifunc::test()
{
  return;
  double x = 0.7;
  cout << "li3(1-x) " << h(0,0,1,1-x) << endl;
  cout << "H(R(0,0,1),1) - H(R(0,1),1) * H(R(1),x) - H(R(1,1,0),x) " << h(0,0,1,double(1)) - h(0,1,double(1)) * h(1,x) - h(1,1,0,x) << endl;
  cout << "S12(1-x) " << h(0,1,1,1-x) << endl;
  cout << "H(R(0,1,1),1) - H(R(1,0,0),x) " << h(0,1,1,double(1)) - h(1,0,0,x) << endl;
  cout << "S12(-x) " << h(0,1,1,-x) << endl;
  cout << "H(R(0,-1,-1),x) " << h(0,-1,-1,x) << endl;

  cout << log(1+x) << "  " << h(-1,x) << endl;
  cout << log(1-x) << "  " << -h(1,x) << endl;
  cout << log(x)   << "  " << h(0,x) << endl;

  cout << " li2_(x)   " <<  h(0,1,x) << endl;
  cout << " li2_(-x)  " <<  h(0,1,-x) << "  " << -h(0,-1,x) << endl;
  cout << " li2_(1-x) " <<  h(0,1,1-x) << "  " << h(0,1,double(1)) + h(1,0,x) << endl;

  cout << " li3(-x) " << h(0,0,1,-x) << "  " <<  -h(0,0,-1,x) << endl;

  double z2 = zeta2;
  double z3 = zeta3;

  int rule = 500;
  double a = 1e-8;
  complex <double> faN = 0.;
  complex <double> feN = 0.;
  complex <double>  N = complex <double>(1.3933786619162052,9.16527808451688547E-003);
  for (int i = 0; i < rule; i++)
    {
      double t = 0.5+0.5*gr::xxx[rule-1][i];
      double x = a*pow(1./a,t);
      double jac = 0.5* x * log(1./a);

      //double x = exp(-double(i)/20.);
      double fa =
	-1.111*pow(log(1-x),3)
	-0.400 *pow(log(1-x),2)
	-2.770 *log(1-x)
	-187.8
	+ 249.6*x
	-146.8 *pow(log(x),2)*log(1-x)
	-93.68*log(x)
	-3.292*pow(log(x),2)
	-1.556*pow(log(x),3)
	-24.89*(1./x);

      double A2HG =
	+ 26*CF*TF
	- 82*CF*TF*x
	+ 80*CF*TF*pow(x,2)
	- 448./27.*CA*TF*pow(x,-1)
       - 4./3.*CA*TF
       - 628./3.*CA*TF*x
       + 6352./27.*CA*TF*pow(x,2)
       - 8*z3*CF*TF
       + 16*z3*CF*TF*x
       + 16*z3*CF*TF*pow(x,2)
       + 32*z3*CA*TF
       + 112*z3*CA*TF*x
       - 8*z2*CF*TF
       - 48*z2*CF*TF*x
      ;
      A2HG +=  + 24*z2*CF*TF*pow(x,2)
       + 16*z2*CA*TF*x
       - 4*z2*CA*TF*pow(x,2)
       - 8*h(-1,x)*z2*CA*TF
       - 16*h(-1,x)*z2*CA*TF*x
       - 16*h(-1,x)*z2*CA*TF*pow(x,2)
       - 16*h(-1,-1,0,x)*CA*TF
       - 32*h(-1,-1,0,x)*CA*TF*x
       - 32*h(-1,-1,0,x)*CA*TF*pow(x,2)
       + 16*h(-1,0,x)*CA*TF
       + 16*h(-1,0,x)*CA*TF*pow(x,2)
       + 8*h(-1,0,0,x)*CA*TF
       + 16*h(-1,0,0,x)*CA*TF*x
       + 16*h(-1,0,0,x)*CA*TF*pow(x,2)
       - 16*h(0,x)*CF*TF
      ;
      A2HG +=  - 18*h(0,x)*CF*TF*x
       - 48*h(0,x)*CF*TF*pow(x,2)
       - 56./3.*h(0,x)*CA*TF
       - 172./3.*h(0,x)*CA*TF*x
       - 1600./9.*h(0,x)*CA*TF*pow(x,2)
       - 2*h(0,0,x)*CF*TF
       - 24*h(0,0,x)*CF*TF*x
       + 40*h(0,0,x)*CF*TF*pow(x,2)
       + 4*h(0,0,x)*CA*TF
       + 16*h(0,0,x)*CA*TF*x
       + 92./3.*h(0,0,x)*CA*TF*pow(x,2)
       + 4*h(0,0,0,x)*CF*TF
       - 8*h(0,0,0,x)*CF*TF*x
       + 16*h(0,0,0,x)*CF*TF*pow(x,2)
       - 8*h(0,0,0,x)*CA*TF
      ;
      A2HG +=  - 16*h(0,0,0,x)*CA*TF*x
       + 8*h(0,1,x)*CF*TF
       + 48*h(0,1,x)*CF*TF*x
       - 24*h(0,1,x)*CF*TF*pow(x,2)
       + 4*h(0,1,x)*CA*TF*pow(x,2)
       - 8*h(0,1,0,x)*CF*TF
       + 16*h(0,1,0,x)*CF*TF*x
       + 16*h(0,1,0,x)*CA*TF
       + 64*h(0,1,0,x)*CA*TF*x
       - 8*h(0,1,1,x)*CF*TF
       + 16*h(0,1,1,x)*CF*TF*x
       - 16*h(0,1,1,x)*CF*TF*pow(x,2)
       + 52*h(1,x)*CF*TF*x
       - 48*h(1,x)*CF*TF*pow(x,2)
       - 4*h(1,x)*CA*TF
      ;
      A2HG +=  - 16*h(1,x)*CA*TF*x
       + 16*h(1,x)*CA*TF*pow(x,2)
       + 4*h(1,0,x)*CF*TF
       - 48*h(1,0,x)*CF*TF*x
       + 40*h(1,0,x)*CF*TF*pow(x,2)
	+ 32./3.*h(1,0,x)*CA*TF*pow(x,-1)
       + 12*h(1,0,x)*CA*TF
       + 64*h(1,0,x)*CA*TF*x
       - 260./3.*h(1,0,x)*CA*TF*pow(x,2)
       + 8*h(1,0,0,x)*CF*TF
       - 16*h(1,0,0,x)*CF*TF*x
       + 16*h(1,0,0,x)*CF*TF*pow(x,2)
       - 8*h(1,0,1,x)*CA*TF
       + 16*h(1,0,1,x)*CA*TF*x
       - 16*h(1,0,1,x)*CA*TF*pow(x,2)
      ;
      A2HG +=  + 8*h(1,1,x)*CF*TF
       + 16*h(1,1,x)*CF*TF*x
       - 24*h(1,1,x)*CF*TF*pow(x,2)
       - 4*h(1,1,x)*CA*TF
       - 16*h(1,1,x)*CA*TF*x
       + 20*h(1,1,x)*CA*TF*pow(x,2)
       - 8*h(1,1,0,x)*CA*TF
       + 16*h(1,1,0,x)*CA*TF*x
       - 16*h(1,1,0,x)*CA*TF*pow(x,2)
       - 8*h(1,1,1,x)*CF*TF
       + 16*h(1,1,1,x)*CF*TF*x
       - 16*h(1,1,1,x)*CF*TF*pow(x,2)
       + 8*h(1,1,1,x)*CA*TF
       - 16*h(1,1,1,x)*CA*TF*x
       + 16*h(1,1,1,x)*CA*TF*pow(x,2)
      ;

      faN += fa * pow(x,N-1.) * jac * gr::www[rule-1][i];
      feN += A2HG * pow(x,N-1.) * jac * gr::www[rule-1][i];
      
      cout << " x " << x << "  " << fa << "  " << A2HG << "  " << (fa-A2HG)/fa << endl;
    }
  cout << N << "  " << faN << "  " << feN << endl;
	
    //−0.006δ(1−x)
  
}

/*
double h(int n1, double z)
{
  return GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(GiNaC::lst(n1),z).eval())).to_double();
}
double h(int n1, int n2, double z)
{
  return GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(GiNaC::lst(n1,n2),z).eval())).to_double();
}
double h(int n1, int n2, int n3, double z)
{
  return GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(GiNaC::lst(n1,n2,n3),z).eval())).to_double();
}
double h(int n1, int n2, int n3, int n4, double z)
{
  return GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(GiNaC::lst(n1,n2,n3,n4),z).eval())).to_double();
}
double h(int n1, int n2, int n3, int n4, int n5, double z)
{
  return GiNaC::ex_to<GiNaC::numeric>((GiNaC::H(GiNaC::lst(n1,n2,n3,n4,n5),z).eval())).to_double();
}
*/

double D0 = 0.; //-> plus distribution 1/(1-z)+
int NF = 5;        //Number of flavours

//C1
double ifunc::I1qq(double z)
{
  return 2*(CF)*(1-z);
}
double ifunc::I1qg(double z)
{
  return 4*(TF)*z*(1-z);
}

//C2
double ifunc::I2qqp(double z)
{
  return  +(CF)*(TF)*(-(8./3.)*((1-z)/(z))*(2*(pow(z,2))-z+2)*(h(1,0,z)+(zeta2))-(2./3.)*(8*(pow(z,2))+3*z+3)*h(0,0,z)+4*(z+1)*h(0,0,0,z)+(4./9.)*(32*(pow(z,2))-30*z+21)*h(0,z)+((2*(1-z)*(136*(pow(z,2))-143*z+172))/(27*z)));
}

double ifunc::I2qqb(double z)
{
  return
    +I2qqp(z)
    +(CF)*((CA)-2*(CF))*(+4*(1-z)*h(1,0,z)+4*(z+1)*h(-1,0,z)+(-11*z-3)*h(0,z)-2*(z-3)*(zeta2)-15*(1-z)-((2*((pow(z,2))+1))/(z+1))*(4*h(-2,0,z)-2*h(2,0,z)-4*h(-1,-1,0,z)+2*h(-1,0,0,z)-h(0,0,0,z)-2*h(-1,z)*(zeta2)+(zeta3)));
}
double ifunc::I2qq(double z)
{
  return
    +I2qqp(z)
    +(D0)*((28*(zeta3)-(808./27.))*(CA)*(CF)+(224./27.)*(NF)*(CF)*(TF))
    +(CA)*(CF)*((1./(1-z))*(2*((pow(z,2))-13)*(zeta3)-2*((pow(z,2))+1)*(2*h(1,2,z)+2*h(2,0,z)+h(0,0,0,z)+2*h(1,1,0,z)))+(1./3.)*(1./(1-z))*((pow(z,2))-12*z-11)*h(0,0,z)-2*(1-z)*(2*h(1,0,z)+3*(zeta2))-(2./9.)*(1./(1-z))*(83*(pow(z,2))-36*z+29)*h(0,z)-2*z*h(1,z)+((8*(z+100))/27.))
    +(CF)*(NF)*(TF)*((4./3.)*(((pow(z,2))+1)/(1-z))*h(0,0,z)+(20./9.)*(((pow(z,2))+1)/(1-z))*h(0,z)-(4./27.)*(19*z+37))+(pow(CF,2))*(4*((1+(pow(z,2)))/(1-z))*(2*h(1,2,z)+2*h(2,0,z)+h(2,1,z)-h(1,0,0,z)+2*h(1,1,0,z)+6*(zeta3))-2*(1./(1-z))*(2*(pow(z,2))-2*z-3)*h(0,0,z)+4*(1-z)*(3*h(1,0,z)+h(2,z)+2*(zeta2))+2*(z+1)*h(0,0,0,z)+2*(1./(1-z))*(16*(pow(z,2))-13*z+5)*h(0,z)+2*z*h(1,z)-22*(1-z));
}
double ifunc::I2qg(double z)
{
  return 
    +(CA)*(TF)*(-(8./3.)*((1-z)/(z))*(11*(pow(z,2))-z+2)*h(1,0,z)+4*(2*(pow(z,2))+2*z+1)*(2*h(-2,0,z)-2*h(-1,-1,0,z)+h(-1,0,0,z)-h(-1,z)*(zeta2))-(2./3.)*(44*(pow(z,2))-12*z+3)*h(0,0,z)+4*(2*(pow(z,2))-2*z+1)*(h(1,2,z)+h(1,1,0,z)-h(1,1,1,z))-8*z*(2*h(2,0,z)-(zeta3))+8*z*(z+1)*h(-1,0,z)-8*(1-z)*z*h(1,1,z)+4*(2*z+1)*h(0,0,0,z)+(8./3.)*(1./(z))*(11*(pow(z,3))-9*(pow(z,2))+3*z-2)*(zeta2)+(4./9.)*(68*(pow(z,2))-30*z+21)*h(0,z)+2*z*(4*z-3)*h(1,z)-((2*(298*(pow(z,3))-387*(pow(z,2))+315*z-172))/(27*z)))
    +(CF)*(TF)*(4*(2*(pow(z,2))-2*z+1)*(h(2,1,z)-h(1,0,0,z)+h(1,1,1,z)+7*(zeta3))+(-8*(pow(z,2))+12*z+1)*h(0,0,z)-2*(4*(pow(z,2))-2*z+1)*h(0,0,0,z)+8*(1-z)*z*(h(1,0,z)+h(1,1,z)+h(2,z)-(zeta2))+(-8*(pow(z,2))+15*z+8)*h(0,z)-2*(4*z-3)*z*h(1,z)-72*(pow(z,2))+75*z-13);
}

//C3

void ifunc::I3(double z)
{
  h5.clear();
  
  double id33 = Id33(z);
  double istqqp = Istqqp(z);
  
  i3qqp = istqqp+((((pow(NC,2))-1)*((pow(NC,2))-4)/(NC)*(TF))/(16*(NC)*((pow(NC,2))-1)))*id33;
  i3qqbp = istqqp-((((pow(NC,2))-1)*((pow(NC,2))-4)/(NC)*(TF))/(16*(NC)*((pow(NC,2))-1)))*id33;
  i3qq = Istqq(z)+i3qqp;
  i3qqb = (CF)*((CA)-2*(CF))*Istqqb(z)+i3qqbp;
  i3qg = I3qg(z);
}



double ifunc::Id33(double z)
{
  return -((1024*(pow(z+1,3)))/(3*z))*(zeta2)*h(-1,-1,z)-((34048*(z+1))/27.)*h(-1,0,z)+((5248*(z+1))/9.)*h(2,1,z)-256*(z+1)*(h(-1,-2,0,z)+h(-1,2,0,z))+((256*(z+1))/3.)*(-5*h(2,z)*(zeta3)-6*h(-1,0,z)*(zeta3)-(3./2.)*h(-1,z)*(zeta4)-6*(zeta2)*h(-1,2,z)-13*(zeta2)*h(2,0,z)-8*(zeta2)*h(2,1,z)+9*h(2,3,z)+3*h(4,1,z)+3*h(-1,3,0,z)+3*(zeta2)*h(-1,0,0,z)+9*(zeta2)*h(0,0,0,z)-4*h(2,-2,0,z)-9*h(2,1,2,z)-2*h(2,2,0,z)+6*h(-1,2,0,0,z)-6*h(-1,2,1,0,z)+h(2,0,0,0,z)-9*h(2,1,0,0,z)-15*h(2,1,1,0,z))+((171520*(1-z))/27.)+(2816./27.)*(9*z-2)*h(0,z)+(256./27.)*(629*z-36)*((1-z)/(z))*h(1,z)+(64./27.)*(1669*z+355)*h(2,z)-(64./27.)*(512*(pow(z,2))+627*z+435)*h(3,z)+(256./9.)*(28*(pow(z,2))+15*z+15)*h(4,z)-(256./3.)*(9*z+7)*h(5,z)-(64./27.)*(841*z+1715)*(zeta2)+(1024./3.)*(5*(pow(z,2))+7)*h(-2,z)*(zeta2)+(64./27.)*(1024*(pow(z,2))+825*z+489)*h(0,z)*(zeta2)-(1024./27.)*(16*(pow(z,2))+13*z+16)*((1-z)/(z))*h(1,z)*(zeta2)+(256./3.)*(9*z-1)*h(3,z)*(zeta2)+(256./27.)*(320*(pow(z,2))-141*z+540)*(zeta3)-(256./3.)*(5*z-7)*(zeta2)*(zeta3)-(64./3.)*(5*z+39)*h(0,z)*(zeta4)-(256./3.)*(15*z+53)*(zeta5)-(512./3.)*(5*z-1)*h(-4,0,z)-(512./9.)*(16*(pow(z,2))-9*z+21)*h(-3,0,z)+(128./27.)*(256*(pow(z,2))+369*z+207)*h(-2,0,z)+(64./27.)*(1171*z-794)*h(0,0,z)-(256./3.)*(16*(pow(z,2))+z+27)*h(-2,2,z)-(128./9.)*(1-z)*(153*h(1,0,z)-91*h(1,1,z))+(512./3.)*(4*z-5)*h(2,0,z)+(256./3.)*(8*(pow(z,2))+3*z+6)*h(2,2,z)-(128./9.)*(16*(pow(z,2))+27*z-3)*h(3,1,z)-(256./3.)*(13*z-5)*h(-3,0,0,z)+(512./3.)*(4*(pow(z,2))-z+1)*h(-2,-1,0,z)-512*(1-z)*h(1,-2,0,z)-(128./9.)*(88*(pow(z,2))-105*z+93)*h(-2,0,0,z)+(1./27.)*((1+z)/(z))*(-384*(128*(pow(z,2))-41*z+128)*h(-1,z)*(zeta2)+256*(128*(pow(z,2))-95*z+128)*h(-1,2,z)-256*(128*(pow(z,2))+67*z+128)*h(-1,-1,0,z)+256*(128*(pow(z,2))+25*z+128)*h(-1,0,0,z))-(128./27.)*(256*(pow(z,2))+261*z+345)*h(0,0,0,z)-(64./9.)*(1-z)*(108*h(1,2,z)+193*h(1,0,0,z)+288*h(1,1,0,z))+(1./9.)*(1./(1+z))*(384*(8*(pow(z,3))+9*(pow(z,2))+2*z+7)*h(2,z)*(zeta2)-384*(24*(pow(z,3))+43*(pow(z,2))+42*z+26)*h(0,0,z)*(zeta2)-256*(44*(pow(z,3))+26*(pow(z,2))-18*z-9)*h(0,z)*(zeta3)+64*(76*(pow(z,3))-173*(pow(z,2))-243*z+15)*(zeta4)+384*(16*(pow(z,3))+9*(pow(z,2))+8*z+12)*h(3,0,z)+128*(16*(pow(z,3))+7*(pow(z,2))-6*z-15)*h(2,0,0,z)+384*(32*(pow(z,3))+35*(pow(z,2))+12*z+15)*h(2,1,0,z))-(512./3.)*(2*z-1)*h(3,0,0,z)-(256./3.)*(1-z)*(2*h(-3,z)*(zeta2)+4*h(-2,-1,z)*(zeta2)-2*h(-2,z)*(zeta3)+2*h(-3,2,z)-h(-2,3,z)-2*h(3,2,z)+8*h(-3,-1,0,z)+2*h(-2,-2,0,z)-2*h(-2,-1,2,z)+2*h(-2,2,0,z)+5*h(3,1,0,z)+4*h(-2,-1,-1,0,z)+11*h(-2,-1,0,0,z)-8*h(-2,0,0,0,z))+(1./9.)*((1+z)/(z))*(256*(4*(pow(z,2))+11*z+4)*h(-1,z)*(zeta3)-384*(8*(pow(z,2))+z+8)*h(-1,3,z)+256*(16*(pow(z,2))+17*z+16)*h(-1,-1,2,z)+512*(2*(pow(z,2))+z+2)*(3*(zeta2)*h(-1,0,z)+2*h(-1,2,1,z))+512*(4*(pow(z,2))-7*z+4)*h(-1,-1,-1,0,z)+384*(8*(pow(z,2))-29*z+8)*h(-1,-1,0,0,z)-2048*((pow(z,2))-4*z+1)*h(-1,0,0,0,z))+(1024./3.)*(2*(pow(z,2))+1)*h(0,0,0,0,z)+(1./9.)*((1-z)/(z))*(-640*(16*(pow(z,2))+z+16)*h(1,z)*(zeta3)-128*(80*(pow(z,2))+77*z+80)*(zeta2)*h(1,0,z)-512*(14*(pow(z,2))+11*z+14)*(zeta2)*h(1,1,z)+128*(32*(pow(z,2))+65*z+32)*h(1,3,z)-384*(16*(pow(z,2))+19*z+16)*h(1,1,2,z)-768*(8*(pow(z,2))-z+8)*h(1,2,0,z)+128*(32*(pow(z,2))-7*z+32)*h(1,0,0,0,z)-128*(16*(pow(z,2))+73*z+16)*h(1,1,0,0,z)-384*(32*(pow(z,2))+29*z+32)*h(1,1,1,0,z))-(512./3.)*(3*h(0,0,0,0,0,z)-13*(zeta3)*h(0,0,z));
}

double ifunc::Istqqp(double z)
{
  return (CF)*(NF)*(pow(TF,2))*((1./27.)*((1-z)/(z))*(16*(4*(pow(z,2))+7*z+4)*h(1,1,1,z)-192*(2*(pow(z,2))-z+2)*(h(1,2,z)-h(1,0,0,z)+2*h(1,1,0,z)+h(1,z)*(zeta2)))+(1./81.)*((1-z)/(z))*(16*(38*(pow(z,2))-79*z+38)*h(1,1,z)-576*((pow(z,2))-z+1)*h(1,0,z))-(32./27.)*(6*(pow(z,2))-5*z-5)*(-h(2,1,z)-2*h(0,z)*(zeta2)+2*h(3,z))-(32./81.)*(18*(pow(z,2))+38*z+137)*h(0,0,z)+(16./27.)*(24*(pow(z,2))-49*z-49)*h(0,0,0,z)+(16./9.)*(z+1)*(-8*(zeta2)*h(0,0,z)-4*h(3,1,z)+2*h(2,1,1,z)-10*h(0,0,0,0,z)-4*h(0,z)*(zeta3)+8*h(4,z)-9*(zeta4))+(32./81.)*((1-z)/(z))*h(1,z)*(75*(pow(z,2))+19*z+75)-(32./81.)*(1./(z))*(39*(pow(z,3))+10*(pow(z,2))+64*z+18)*(zeta2)+(32./27.)*(1./(z))*(18*(pow(z,3))-23*(pow(z,2))+13*z-12)*(zeta3)+(16./243.)*h(0,z)*(534*(pow(z,2))-337*z-661)+(32./81.)*h(2,z)*(57*(pow(z,2))-26*z+100)+((32*(1-z)*(1571*(pow(z,2))-2689*z+1058))/(729*z)))+(pow(CF,2))*(TF)*(-((2*(1-z)*(7512*(pow(z,2))+56*z+2421))/(81*z))+(2./81.)*(5720*(pow(z,2))-8308*z+2707)*h(0,z)-((2*(1-z))/(81*z))*(7088*(pow(z,2))-5805*z+4343)*h(1,z)-(4./81.)*(2882*(pow(z,2))+75*z-1524)*h(2,z)+(8./9.)*(104*(pow(z,2))-55*z+229)*h(3,z)-(16./9.)*(40*(pow(z,2))-27*z-24)*h(4,z)+(4./(81*z))*(2774*(pow(z,3))+687*(pow(z,2))-1380*z-648)*(zeta2)-(16./9.)*(60*(pow(z,2))-26*z+149)*h(0,z)*(zeta2)-(16./3.)*(4*(pow(z,2))+7*z+14)*h(2,z)*(zeta2)-(4./(27*z))*(1528*(pow(z,3))-999*(pow(z,2))-720*z-768)*(zeta3)+(32./9.)*(38*(pow(z,2))+81*z+42)*h(0,z)*(zeta3)-(4./(9*z))*(52*(pow(z,3))+111*(pow(z,2))+486*z-48)*(zeta4)-(2./81.)*(5864*(pow(z,2))+9273*z+2733)*h(0,0,z)+(16./9.)*(52*(pow(z,2))-36*z-15)*(zeta2)*h(0,0,z)+(1./81.)*((1-z)/(z))*(8*(362*(pow(z,2))+161*z+101)*h(1,0,z)-4*(406*(pow(z,2))+2557*z+361)*h(1,1,z))+(16./27.)*(68*(pow(z,2))+123*z-15)*h(2,0,z)-(4./27.)*(184*(pow(z,2))+423*z+612)*h(2,1,z)+(16./3.)*(10*z+11)*h(2,2,z)-(16./9.)*(4*(pow(z,2))+45*z+12)*h(3,0,z)+(16./9.)*(16*(pow(z,2))+9*z-6)*h(3,1,z)+(4./9.)*(376*(pow(z,2))-167*z+257)*h(0,0,0,z)+(1./27.)*((1-z)/(z))*(8*(8*(pow(z,2))-493*z+8)*h(1,z)*(zeta2)+16*(20*(pow(z,2))+203*z+20)*h(1,2,z)-16*(26*(pow(z,2))-160*z-1)*h(1,0,0,z)-8*(8*(pow(z,2))+209*z+8)*h(1,1,0,z)+12*(40*(pow(z,2))+47*z+4)*h(1,1,1,z))+(16./3.)*(z-2)*(4*z-5)*h(2,0,0,z)-(16./3.)*(4*(pow(z,2))+2*z+7)*h(2,1,0,z)+(16./9.)*(4*(pow(z,2))+21*z+9)*h(2,1,1,z)-(8./9.)*(140*(pow(z,2))-15*z+66)*h(0,0,0,0,z)+(1./9.)*((1-z)/(z))*(96*(4*(pow(z,2))-11*z+4)*h(1,z)*(zeta3)-16*(20*(pow(z,2))-19*z+20)*h(1,3,z)+64*(5*(pow(z,2))+2*z+5)*h(1,1,2,z)+16*(8*(pow(z,2))-13*z+8)*(2*(zeta2)*h(1,1,z)+h(1,2,0,z))-8*(52*(pow(z,2))-17*z+52)*h(1,0,0,0,z)+32*(2*(pow(z,2))+17*z+2)*h(1,1,0,0,z)+16*(32*(pow(z,2))-25*z+32)*((zeta2)*h(1,0,z)+h(1,1,1,0,z))-16*(4*(pow(z,2))+7*z+4)*h(1,1,1,1,z))+(16./3.)*(z+1)*(14*h(5,z)-12*h(2,z)*(zeta3)+7*(zeta2)*(zeta3)-14*h(0,z)*(zeta4)-36*(zeta5)-18*(zeta3)*h(0,0,z)-2*(zeta2)*h(2,0,z)-4*(zeta2)*h(2,1,z)+2*h(2,3,z)+4*h(4,0,z)-6*h(4,1,z)-14*(zeta2)*h(0,0,0,z)+4*h(2,1,2,z)-2*h(2,2,0,z)+4*h(3,0,0,z)-2*h(3,1,0,z)-h(3,1,1,z)-h(2,0,0,0,z)+8*h(2,1,0,0,z)-2*h(2,1,1,0,z)-2*h(2,1,1,1,z)+12*h(0,0,0,0,0,z)))+(CA)*(CF)*(TF)*(-((4*(1-z)*(356788*(pow(z,2))-36824*z+228133))/(729*z))-(2./(243*z))*(214384*(pow(z,3))+34691*(pow(z,2))+143678*z+17152)*h(0,z)+((2*(1-z))/(243*z))*(15520*(pow(z,2))-3245*z+14944)*h(1,z)+(4./27.)*(224*(pow(z,2))-451*z-724)*h(3,z)+(4./9.)*(8*(pow(z,2))-91*z-109)*h(4,z)-(8./3.)*(20*(pow(z,2))-7*z+27)*h(-2,z)*(zeta2)+(1./81.)*(1./(z))*(4*(1000*(pow(z,3))+2969*(pow(z,2))-2068*z+1256)*h(2,z)-8*(3932*(pow(z,3))-2936*(pow(z,2))+1099*z-3002)*(zeta2))-(8./3.)*(27*z+11)*(zeta2)*(zeta3)+(2./3.)*(5*z-201)*h(0,z)*(zeta4)+32*(9*z-1)*(zeta5)+(16./3.)*(13*z-25)*h(-4,0,z)+(8./9.)*(112*(pow(z,2))-99*z+87)*h(-3,0,z)-(8./27.)*(544*(pow(z,2))+93*z+576)*h(-2,0,z)+(8./3.)*(16*(pow(z,2))+z+27)*h(-2,2,z)+(4./27.)*(828*(pow(z,2))-77*z+906)*((z+1)/(z))*h(-1,0,z)+(4./81.)*(16868*(pow(z,2))+3176*z+14795)*h(0,0,z)-(208./3.)*(z+2)*(zeta3)*h(0,0,z)-20*(1-z)*(zeta2)*h(1,0,z)+(1./81.)*((1-z)/(z))*(4*(6272*(pow(z,2))+272*z+4481)*h(1,0,z)+4*(184*(pow(z,2))+2098*z+463)*h(1,1,z))+(1./27.)*(1./(z))*(8*(254*(pow(z,3))+731*(pow(z,2))+776*z+156)*h(0,z)*(zeta2)-4*(700*(pow(z,3))-4100*(pow(z,2))+2203*z-1620)*(zeta3)+24*(124*(pow(z,3))+123*(pow(z,2))+144*z+52)*h(2,0,z)-4*(40*(pow(z,3))-488*(pow(z,2))-371*z-116)*h(2,1,z))+(4./9.)*(8*(pow(z,2))+35*z+59)*h(3,1,z)-(16./3.)*(3*z+5)*h(3,2,z)-64*z*h(4,0,z)+(8./3.)*(29*z-37)*h(-3,0,0,z)-(64./3.)*(z-2)*z*h(-2,-1,0,z)+(4./9.)*(184*(pow(z,2))-315*z+159)*h(-2,0,0,z)+(1./27.)*((z+1)/(z))*(16*(95*(pow(z,2))-35*z+68)*h(-1,z)*(zeta2)-8*(116*(pow(z,2))-101*z+116)*h(-1,2,z)+16*(74*(pow(z,2))+31*z+20)*h(-1,-1,0,z)-4*(592*(pow(z,2))-25*z+484)*h(-1,0,0,z))+8*(z+1)*h(-1,2,0,z)-(4./27.)*(1758*(pow(z,2))-587*z+1261)*h(0,0,0,z)+(1./27.)*((1-z)/(z))*(4*(748*(pow(z,2))+475*z+748)*h(1,z)*(zeta2)+8*(2*z-5)*(67*z-16)*h(1,2,z)-24*(249*(pow(z,2))-2*z+249)*h(1,0,0,z)+16*(257*(pow(z,2))+11*z+230)*h(1,1,0,z)-4*(76*(pow(z,2))+103*z-32)*h(1,1,1,z))+(1./9.)*(1./(z*(z+1)))*(12*(24*(pow(z,4))+87*(pow(z,3))+120*(pow(z,2))+79*z+16)*h(2,z)*(zeta2)+8*(136*(pow(z,4))+47*(pow(z,3))-136*(pow(z,2))-14*z+24)*h(0,z)*(zeta3)+(672*(pow(z,4))+4935*(pow(z,3))+4956*(pow(z,2))+2551*z+1840)*(zeta4)-8*(28*(pow(z,4))+109*(pow(z,3))+141*(pow(z,2))+141*z+72)*h(2,0,0,z))+(1./9.)*(1./(z+1))*(-4*(8*(pow(z,3))-2*(pow(z,2))-56*z-37)*(zeta2)*h(0,0,z)+12*(47*(pow(z,2))+26*z-24)*h(3,0,z)+4*(112*(pow(z,3))+265*(pow(z,2))+294*z+159)*h(2,1,0,z))+(1./(9*z))*(48*(4*(pow(z,3))-7*(pow(z,2))-6*z-4)*h(2,2,z)-8*(4*(pow(z,3))+35*(pow(z,2))+11*z-4)*h(2,1,1,z))-(16./3.)*(11*z-6)*h(3,0,0,z)+(8./3.)*(3*z-11)*h(3,1,0,z)-(8./3.)*(1-z)*(h(5,z)-2*h(-3,z)*(zeta2)+7*h(3,z)*(zeta2)-2*h(-2,z)*(zeta3)-2*h(-3,2,z)-8*(zeta2)*h(-2,0,z)+h(-2,3,z)-8*h(-3,-1,0,z)-10*h(-2,-2,0,z)+2*h(-2,-1,2,z)-2*h(-2,2,0,z)+4*h(-2,-1,-1,0,z)-23*h(-2,-1,0,0,z)+16*h(-2,0,0,0,z))+(1./9.)*((z+1)/(z))*(-24*(4*(pow(z,2))-z+4)*h(-1,z)*(zeta3)-16*(14*(pow(z,2))-11*z+14)*(zeta2)*h(-1,0,z)+12*(8*(pow(z,2))+z+8)*h(-1,3,z)-8*(16*(pow(z,2))-37*z+16)*h(-1,-2,0,z)-8*(16*(pow(z,2))+17*z+16)*h(-1,-1,2,z)-16*(2*(pow(z,2))+z+2)*(2*h(-1,2,1,z)-5*(zeta2)*h(-1,-1,z))+16*(4*(pow(z,2))-7*z+4)*h(-1,-1,-1,0,z)-36*(8*(pow(z,2))-19*z+8)*h(-1,-1,0,0,z)+96*(z-2)*(2*z-1)*h(-1,0,0,0,z))+(8./9.)*(25*z+121)*h(0,0,0,0,z)+(1./9.)*((1-z)/(z))*(-32*((pow(z,2))-5*z+1)*(zeta2)*h(1,1,z)-4*(64*(pow(z,2))-5*z+64)*h(1,3,z)+16*(8*(pow(z,2))+5*z+8)*h(1,-2,0,z)-4*(32*(pow(z,2))+29*z+32)*h(1,1,2,z)-24*(16*(pow(z,2))+13*z+16)*h(1,2,0,z)+4*(104*(pow(z,2))+119*z+104)*h(1,0,0,0,z)-28*(16*(pow(z,2))+19*z+16)*h(1,1,0,0,z)-4*(32*(pow(z,2))-25*z+32)*(h(1,1,1,0,z)-h(1,z)*(zeta3))+16*(4*(pow(z,2))+7*z+4)*h(1,1,1,1,z))-(8./3.)*(z+1)*(h(2,z)*(zeta3)+6*h(-1,0,z)*(zeta3)+(3./2.)*h(-1,z)*(zeta4)+6*(zeta2)*h(-1,2,z)+5*(zeta2)*h(2,0,z)-4*(zeta2)*h(2,1,z)+3*h(2,3,z)+h(4,1,z)-3*(zeta2)*h(-1,0,0,z)-3*h(-1,3,0,z)-(zeta2)*h(0,0,0,z)-4*h(2,-2,0,z)+5*h(2,1,2,z)+14*h(2,2,0,z)-2*h(3,1,1,z)-6*h(-1,2,0,0,z)+6*h(-1,2,1,0,z)-19*h(2,0,0,0,z)+21*h(2,1,0,0,z)-h(2,1,1,0,z)-4*h(2,1,1,1,z))+16*(3*z-4)*h(0,0,0,0,0,z));
}

double ifunc::Istqqb(double z)
{
  return (NF)*(TF)*((1./81.)*(1./(z+1))*(448*((pow(z,2))-6*z+1)*h(-1,0,z)+8*(23*(pow(z,2))+54*z-193)*h(0,0,z)+16*(137*(pow(z,2))-18*z-43)*(zeta2))+(1./27.)*(1./(z+1))*(32*(53*(pow(z,2))+18*z+35)*h(-2,0,z)-32*(7*(pow(z,2))-6*z+7)*h(-1,2,z)-48*(13*(pow(z,2))+6*z+13)*h(2,0,z)-192*(7*(pow(z,2))+4*z+7)*h(-1,-1,0,z)+16*(49*(pow(z,2))+18*z+49)*h(-1,0,0,z)-16*(43*(pow(z,2))+36*z+43)*h(0,0,0,z)-64*h(-1,z)*(7*(pow(z,2))+9*z+7)*(zeta2)-16*(5*(pow(z,2))+18*z+23)*(zeta2)*h(0,z)+16*h(3,z)*(19*(pow(z,2))+18*z+19))+(16./9.)*(1./(z+1))*((pow(z,2))+1)*(-4*(zeta2)*h(-1,-1,z)+4*(zeta2)*h(-1,0,z)-4*(zeta2)*h(0,0,z)+20*h(-3,0,z)-14*h(-2,2,z)-8*h(-1,3,z)+6*h(2,2,z)-9*h(3,0,z)-2*h(3,1,z)-20*h(-2,-1,0,z)+17*h(-2,0,0,z)-20*h(-1,-2,0,z)+12*h(-1,-1,2,z)+6*h(-1,2,0,z)+4*h(-1,2,1,z)-9*h(2,0,0,z)+12*h(2,1,0,z)+16*h(-1,-1,-1,0,z)-14*h(-1,-1,0,0,z)+11*h(-1,0,0,0,z)-8*h(0,0,0,0,z)+4*h(-2,z)*(zeta2)+6*h(2,z)*(zeta2)+2*h(-1,z)*(zeta3)-h(0,z)*(zeta3)+5*h(4,z)+6*(zeta4))+(16./3.)*(1-z)*(2*h(1,2,z)-3*h(1,0,0,z)+4*h(1,1,0,z)+2*h(1,z)*(zeta2))-(32./9.)*(z+1)*(h(2,1,z)-(zeta3))-(64./9.)*(1-z)*(h(1,0,z)+h(1,1,z))-(592./27.)*(1-z)*h(1,z)+(32./81.)*h(0,z)*(47*z+11)-(16./27.)*h(2,z)*(29*z-7)+((392*(1-z))/81.))+(CA)*(((10832*(1-z))/27.)*h(1,z)-((8*(1-z))/9.)*(17*h(1,0,z)-70*h(1,1,z))-((4*(1-z))/3.)*(-47*h(1,z)*(zeta2)+86*h(1,2,z)+41*h(1,0,0,z)+67*h(1,1,0,z))+((16*(1-z))/3.)*h(-2,-1,-1,0,z)-((16*(1-z))/3.)*(-22*h(1,z)*(zeta3)-20*(zeta2)*h(1,0,z)-9*(zeta2)*h(1,1,z)+11*h(1,3,z)+8*h(1,-2,0,z)-13*h(1,1,2,z)-13*h(1,2,0,z)+11*h(1,0,0,0,z)-h(1,1,0,0,z)-20*h(1,1,1,0,z))+((22292*(1-z))/81.)-(4./81.)*(3065*(pow(z,2))+2287*z-859)*(1./(z+1))*h(0,z)+(4./27.)*(1744*z+439)*h(2,z)-(4./(81*z*(z+1)))*(162*(pow(z,4))+1619*(pow(z,3))-723*(pow(z,2))+1457*z+81)*h(-1,0,z)+(1./81.)*(1./(1+z))*(2*(324*(pow(z,3))+6287*(pow(z,2))+4590*z+2183)*h(0,0,z)-2*(324*(pow(z,3))+9473*(pow(z,2))+12294*z+6701)*(zeta2))+(280./9.)*(z+1)*h(2,1,z)+(1./27.)*(1./(z+1))*(4*(73*(pow(z,2))+81*z-296)*h(3,z)+4*(1133*(pow(z,2))+2142*z+1205)*h(-1,z)*(zeta2)-4*(689*(pow(z,2))+738*z-22)*h(0,z)*(zeta2)-6*(41*(pow(z,2))+592*z+515)*(zeta3)-4*(1415*(pow(z,2))+486*z+983)*h(-2,0,z)-8*(259*(pow(z,2))+822*z+259)*h(-1,2,z)+12*(185*(pow(z,2))+33*z+116)*h(2,0,z)+24*(205*(pow(z,2))+166*z+229)*h(-1,-1,0,z)-8*(709*(pow(z,2))+864*z+709)*h(-1,0,0,z)+4*(1307*(pow(z,2))+972*z+470)*h(0,0,0,z))+(1./9.)*(1./(z+1))*(-4*(193*(pow(z,2))+186*z+103)*h(4,z)-4*(533*(pow(z,2))+513*z+41)*h(-2,z)*(zeta2)-12*((pow(z,2))-28*z-3)*h(2,z)*(zeta2)-4*(91*(pow(z,2))+141*z+67)*h(-1,z)*(zeta3)+4*(35*(pow(z,2))+21*z-19)*h(0,z)*(zeta3)+3*(145*(pow(z,2))+249*z+279)*(zeta4)-8*(95*(pow(z,2))-39*z+59)*h(-3,0,z)+8*(314*(pow(z,2))+261*z+101)*h(-2,2,z)+4*(197*(pow(z,2))+309*z+200)*(zeta2)*h(-1,-1,z)-4*(32*(pow(z,2))+15*z+62)*(zeta2)*h(-1,0,z)+64*(10*(pow(z,2))+9*z+10)*h(-1,3,z)+4*(134*(pow(z,2))+129*z+65)*(zeta2)*h(0,0,z)-24*(53*(pow(z,2))+58*z+27)*h(2,2,z)-12*(11*(pow(z,2))+62*z-15)*h(3,0,z)+8*(47*(pow(z,2))+48*z+23)*h(3,1,z)+8*(95*(pow(z,2))+9*z+161)*h(-2,-1,0,z)-4*(31*(pow(z,2))-168*z+184)*h(-2,0,0,z)+8*(134*(pow(z,2))+39*z+98)*h(-1,-2,0,z)-48*(23*(pow(z,2))+24*z+23)*h(-1,-1,2,z)-24*(15*(pow(z,2))+8*z+6)*h(-1,2,0,z)-16*(35*(pow(z,2))+48*z+35)*h(-1,2,1,z)-12*(15*(pow(z,2))+68*z+11)*h(2,0,0,z)-12*(131*(pow(z,2))+112*z+51)*h(2,1,0,z)-8*(79*(pow(z,2))-21*z+76)*h(-1,-1,-1,0,z)+44*(17*(pow(z,2))+3*z+14)*h(-1,-1,0,0,z)-8*(59*(pow(z,2))-30*z+50)*h(-1,0,0,0,z)+4*(67*(pow(z,2))-72*z+64)*h(0,0,0,0,z))+(1./3.)*(1./(z+1))*(-4*(23*(pow(z,2))+25)*h(5,z)-16*(30*(pow(z,2))+29)*h(-3,z)*(zeta2)-8*(105*(pow(z,2))+107)*h(-2,z)*(zeta3)+16*(8*(pow(z,2))+5)*(zeta2)*(zeta3)+(197*(pow(z,2))+231)*h(0,z)*(zeta4)+8*(11*(pow(z,2))+30)*(zeta5)+8*(13*(pow(z,2))+7)*h(-4,0,z)+8*(71*(pow(z,2))+73)*h(-3,2,z)+32*(37*(pow(z,2))+38)*(zeta2)*h(-2,-1,z)+4*(147*(pow(z,2))+145)*h(-2,3,z)+4*(37*(pow(z,2))+11)*(zeta3)*h(0,0,z)-8*(15*(pow(z,2))+17)*h(3,2,z)+16*(11*(pow(z,2))+15)*h(-3,-1,0,z)+4*(59*(pow(z,2))+41)*h(-3,0,0,z)+8*(9*(pow(z,2))+11)*h(-2,-2,0,z)-8*(149*(pow(z,2))+151)*h(-2,-1,2,z)-8*(9*(pow(z,2))+7)*h(-2,2,0,z)-4*(29*(pow(z,2))+35)*h(3,0,0,z)-4*(21*(pow(z,2))+11)*(h(3,z)*(zeta2)+h(3,1,0,z))-4*(133*(pow(z,2))+111)*h(-2,-1,0,0,z)+8*(33*(pow(z,2))+25)*h(-2,0,0,0,z)+8*((pow(z,2))+1)*(44*h(2,z)*(zeta3)+113*h(-1,-1,z)*(zeta3)-22*h(-1,0,z)*(zeta3)-34*h(-1,z)*(zeta4)-94*(zeta2)*h(-2,0,z)+138*(zeta2)*h(-1,-2,z)+2*(zeta2)*h(-1,2,z)+36*h(-1,4,z)+40*(zeta2)*h(2,0,z)+18*(zeta2)*h(2,1,z)-22*h(2,3,z)-6*h(4,0,z)+4*h(4,1,z)-16*h(-2,2,1,z)-20*h(-1,-3,0,z)-150*h(-1,-2,2,z)-168*(zeta2)*h(-1,-1,-1,z)+95*(zeta2)*h(-1,-1,0,z)-84*h(-1,-1,3,z)-34*(zeta2)*h(-1,0,0,z)+58*h(-1,2,2,z)+31*h(-1,3,0,z)-16*h(-1,3,1,z)+14*(zeta2)*h(0,0,0,z)-16*h(2,-2,0,z)+26*h(2,1,2,z)+26*h(2,2,0,z)-24*h(-1,-2,-1,0,z)-57*h(-1,-2,0,0,z)-18*h(-1,-1,-2,0,z)+168*h(-1,-1,-1,2,z)+14*h(-1,-1,2,0,z)+32*h(-1,-1,2,1,z)+34*h(-1,2,0,0,z)+56*h(-1,2,1,0,z)-22*h(2,0,0,0,z)+2*h(2,1,0,0,z)+40*h(2,1,1,0,z)+60*h(-1,-1,-1,0,0,z)-38*h(-1,-1,0,0,0,z)+16*h(-1,0,0,0,0,z))-12*(5*(pow(z,2))+3)*h(0,0,0,0,0,z)))+(CF)*(-((1532*(1-z))/3.)*h(1,z)-80*(1-z)*(h(1,0,z)+h(1,1,z))-((16*(1-z))/3.)*h(-2,2,0,z)+((4*(1-z))/3.)*(-129*h(1,z)*(zeta2)+101*h(1,2,z)+174*h(1,0,0,z)+15*h(1,1,0,z))+((16*(1-z))/3.)*(-47*h(1,z)*(zeta3)-38*(zeta2)*h(1,0,z)-16*(zeta2)*h(1,1,z)+24*h(1,3,z)+2*h(1,-2,0,z)-19*h(1,1,2,z)-13*h(1,2,0,z)+21*h(1,0,0,0,z)+6*h(1,1,0,0,z)-32*h(1,1,1,0,z))+((1294*(1-z))/3.)+(4./3.)*(638*(pow(z,2))+703*z+62)*(1./(z+1))*h(0,z)-(4./3.)*(205*z+103)*h(2,z)+(8./3.)*(2*(pow(z,4))-27*(pow(z,3))-65*(pow(z,2))-29*z+1)*(1./(z*(z+1)))*h(-1,0,z)+(1./3.)*(1./(z+1))*(2*(8*(pow(z,3))+451*(pow(z,2))+484*z+53)*(zeta2)-2*(8*(pow(z,3))+671*(pow(z,2))+670*z+19)*h(0,0,z))-(4./3.)*(56*z+17)*h(2,0,z)-(8./3.)*(11*z+19)*h(2,1,z)-(8./3.)*(43*z+51)*h(-1,-1,0,z)+(176./3.)*(z+1)*h(-1,2,0,z)+(1./3.)*(1./(z+1))*(-4*(85*(pow(z,2))+87*z-30)*h(3,z)-4*(141*(pow(z,2))+354*z+149)*h(-1,z)*(zeta2)+4*(160*(pow(z,2))+151*z-30)*h(0,z)*(zeta2)+2*(395*(pow(z,2))+368*z-123)*(zeta3)+4*(167*(pow(z,2))+162*z+27)*h(-2,0,z)+8*(49*(pow(z,2))+130*z+49)*h(-1,2,z)+16*(45*(pow(z,2))+82*z+45)*h(-1,0,0,z)-4*(187*(pow(z,2))+177*z+33)*h(0,0,0,z))+(16./3.)*(13*z+25)*h(2,0,0,z)+(8./3.)*(9*z+11)*h(-1,-1,-1,0,z)+(1./3.)*(1./(z+1))*(8*(43*(pow(z,2))+50*z+28)*h(4,z)+4*(271*(pow(z,2))+220*z+9)*h(-2,z)*(zeta2)-4*(27*(pow(z,2))+68*z+47)*h(2,z)*(zeta2)+8*(27*(pow(z,2))+32*z+26)*h(-1,z)*(zeta3)-4*(109*(pow(z,2))+140*z+49)*h(0,z)*(zeta3)-2*(56*(pow(z,2))+510*z+631)*(zeta4)-8*(13*(pow(z,2))+22*z-18)*h(-3,0,z)-8*(135*(pow(z,2))+118*z+28)*h(-2,2,z)-4*(99*(pow(z,2))+124*z+97)*(zeta2)*h(-1,-1,z)+4*(29*(pow(z,2))+32*z+33)*(zeta2)*h(-1,0,z)-16*(11*(pow(z,2))+10*z+11)*h(-1,3,z)-4*(93*(pow(z,2))+104*z+44)*(zeta2)*h(0,0,z)+4*(125*(pow(z,2))+156*z+73)*h(2,2,z)+4*(29*(pow(z,2))+44*z-12)*h(3,0,z)-8*(25*(pow(z,2))+32*z+13)*h(3,1,z)+8*((pow(z,2))-16*z-47)*h(-2,-1,0,z)-4*(108*(pow(z,2))+98*z-61)*h(-2,0,0,z)-8*(37*(pow(z,2))+56*z+37)*h(-1,-2,0,z)+144*(3*(pow(z,2))+4*z+3)*h(-1,-1,2,z)+48*(5*(pow(z,2))+8*z+5)*h(-1,2,1,z)+4*(131*(pow(z,2))+128*z+27)*h(2,1,0,z)-4*(37*(pow(z,2))+36*z+35)*h(-1,-1,0,0,z)+8*(13*(pow(z,2))-4*z+10)*h(-1,0,0,0,z)+12*(16*(pow(z,2))+26*z-5)*h(0,0,0,0,z))+(1./3.)*(1./(z+1))*(8*(29*(pow(z,2))+31)*h(5,z)+32*(34*(pow(z,2))+33)*h(-3,z)*(zeta2)+16*h(3,z)*(zeta2)+8*(31*(pow(z,2))+29)*(zeta2)*(zeta3)-2*(353*(pow(z,2))+267)*h(0,z)*(zeta4)-4*(313*(pow(z,2))+231)*(zeta5)-16*(29*(pow(z,2))+7)*h(-4,0,z)-32*(31*(pow(z,2))+32)*h(-3,2,z)-16*(119*(pow(z,2))+121)*(zeta2)*h(-2,-1,z)+64*(22*(pow(z,2))+21)*(zeta2)*h(-2,0,z)-16*(69*(pow(z,2))+68)*h(-2,3,z)-8*(57*(pow(z,2))+31)*(zeta3)*h(0,0,z)+16*(15*(pow(z,2))+17)*h(3,2,z)+16*(11*(pow(z,2))+5)*h(4,0,z)-16*(59*(pow(z,2))+38)*h(-3,0,0,z)+96*(2*(pow(z,2))+1)*h(-2,-2,0,z)+32*(58*(pow(z,2))+59)*h(-2,-1,2,z)+56*(9*(pow(z,2))+7)*h(3,0,0,z)+8*(11*(pow(z,2))+13)*h(3,1,0,z)+272*(5*(pow(z,2))+4)*h(-2,-1,0,0,z)-24*(33*(pow(z,2))+25)*h(-2,0,0,0,z)-8*((pow(z,2))+1)*(-169*h(-2,z)*(zeta3)+94*h(2,z)*(zeta3)+177*h(-1,-1,z)*(zeta3)-90*h(-1,0,z)*(zeta3)-62*h(-1,z)*(zeta4)+234*(zeta2)*h(-1,-2,z)-10*(zeta2)*h(-1,2,z)+66*h(-1,4,z)+76*(zeta2)*h(2,0,z)+32*(zeta2)*h(2,1,z)-48*h(2,3,z)+12*h(4,1,z)-28*h(-2,2,1,z)-56*h(-1,-3,0,z)-234*h(-1,-2,2,z)-264*(zeta2)*h(-1,-1,-1,z)+183*(zeta2)*h(-1,-1,0,z)-148*h(-1,-1,3,z)-72*(zeta2)*h(-1,0,0,z)+78*h(-1,2,2,z)+37*h(-1,3,0,z)-32*h(-1,3,1,z)+32*(zeta2)*h(0,0,0,z)-4*h(2,-2,0,z)+38*h(2,1,2,z)+26*h(2,2,0,z)+12*h(-2,-1,-1,0,z)-155*h(-1,-2,0,0,z)+6*h(-1,-1,-2,0,z)+264*h(-1,-1,-1,2,z)+10*h(-1,-1,2,0,z)+48*h(-1,-1,2,1,z)+76*h(-1,2,0,0,z)+64*h(-1,2,1,0,z)-42*h(2,0,0,0,z)-12*h(2,1,0,0,z)+64*h(2,1,1,0,z)+156*h(-1,-1,-1,0,0,z)-104*h(-1,-1,0,0,0,z)+54*h(-1,0,0,0,0,z))+8*(3*(pow(z,2))+1)*(8*h(-3,-1,0,z)+9*h(0,0,0,0,0,z))));
}

double ifunc::Istqq(double z)
{
  return (D0)*((CA)*(CF)*(NF)*(TF)*(-((1648*(zeta2))/81.)-((1808*(zeta3))/27.)+((40*(zeta4))/3.)+(125252./729.))+(pow(CA,2))*(CF)*(-(176./3.)*(zeta3)*(zeta2)+((6392*(zeta2))/81.)+((12328*(zeta3))/27.)+((154*(zeta4))/3.)-192*(zeta5)-(297029./729.))+(CF)*(pow(NF,2))*(pow(TF,2))*(-((128*(zeta3))/9.)-(7424./729.))+(pow(CF,2))*(NF)*(TF)*(-((608*(zeta3))/9.)-32*(zeta4)+(3422./27.)))+(CF)*(pow(NF,2))*(pow(TF,2))*(-(32./81.)*(1./(1-z))*(37*(pow(z,2))-24*z+37)*h(0,0,z)-(160./27.)*(1./(1-z))*((pow(z,2))+1)*h(0,0,0,z)-(32./81.)*(1./(1-z))*h(0,z)*(43*(pow(z,2))-34*z+43)+(64./9.)*(z+1)*(zeta3)+(64./729.)*(157*z-41))+(CA)*(CF)*(NF)*(TF)*((1./81.)*(1./(1-z))*(8*(1322*(pow(z,2))-882*z+1247)*h(0,0,z)+144*((pow(z,2))-6*z+4)*h(1,0,z)-24*h(2,z)*((pow(z,2))+27*z-25)+8*(47*(pow(z,2))-231*z+175)*(zeta2))+(1./27.)*(1./(1-z))*(24*(30*(pow(z,2))-27*z+37)*h(1,2,z)+24*(34*(pow(z,2))-17*z+26)*h(2,0,z)+16*(41*(pow(z,2))+21*z+98)*h(0,0,0,z)+96*(4*(pow(z,2))-13*z+4)*h(1,0,0,z)+24*(16*(pow(z,2))+15*z+9)*h(1,1,0,z)-8*h(0,z)*(8*(pow(z,2))+3*z+20)*(zeta2)+8*h(3,z)*(16*(pow(z,2))-33*z+28)+8*(87*(pow(z,2))-51*z+391)*(zeta3))+(1./9.)*(1./(1-z))*(-16*(2*(pow(z,2))+3*z+5)*(zeta2)*h(0,0,z)+16*((pow(z,2))+1)*(-7*(zeta2)*h(1,0,z)-4*(zeta2)*h(1,1,z)+9*h(1,3,z)-h(3,1,z)-4*h(1,1,2,z)+3*h(1,2,0,z)-3*h(1,2,1,z)+h(2,0,0,z)+8*h(0,0,0,0,z)-8*h(1,0,0,0,z)+5*h(1,1,0,0,z)-8*h(1,1,1,0,z)-5*h(1,z)*(zeta3))+16*((pow(z,2))+3*z+4)*(h(2,2,z)+h(4,z))+48*(4*(pow(z,2))-z+3)*h(3,0,z)+16*(5*(pow(z,2))-3*z+2)*h(2,1,0,z)+16*h(2,z)*((pow(z,2))-3*z-2)*(zeta2)+16*h(0,z)*(4*(pow(z,2))+9*z+13)*(zeta3)+12*(21*(pow(z,2))-14*z-3)*(zeta4))-(16./9.)*(z+1)*h(2,1,z)-((8*h(1,1,z))/3.)+(80./81.)*(1./(1-z))*h(0,z)*(157*(pow(z,2))-121*z+168)+(8./9.)*h(1,z)*(18*z-25)*(zeta2)+(64./27.)*h(1,z)*(5*z+1)-(346./729.)*(451*z-89))+(pow(CF,2))*(NF)*(TF)*((1./81.)*(1./(1-z))*(-16*(349*(pow(z,2))-474*z+503)*h(0,0,z)-16*(35*(pow(z,2))-312*z+53)*h(1,0,z)+8*h(2,z)*(146*(pow(z,2))+174*z+191)-72*(36*(pow(z,2))-70*z+41)*(zeta2))+(1./27.)*(1./(1-z))*(-96*(13*(pow(z,2))-6*z+13)*h(1,2,z)-16*(88*(pow(z,2))-72*z+73)*h(2,0,z)-192*(3*(pow(z,2))-z+3)*h(2,1,z)+8*(191*(pow(z,2))-126*z-169)*h(0,0,0,z)+16*((pow(z,2))+138*z+1)*h(1,0,0,z)-192*(3*(pow(z,2))+4*z+3)*h(1,1,0,z)-16*h(0,z)*(16*(pow(z,2))-24*z+37)*(zeta2)+16*h(3,z)*(8*(pow(z,2))+12*z+29)-16*(344*(pow(z,2))-138*z+221)*(zeta3))+(1./9.)*(1./(1-z))*(32*((pow(z,2))+1)*(-2*(zeta2)*h(0,0,z)+3*(zeta2)*h(1,0,z)+2*(zeta2)*h(1,1,z)-5*h(1,3,z)-4*h(2,2,z)-7*h(3,0,z)-2*h(3,1,z)+6*h(1,1,2,z)-5*h(1,2,0,z)+4*h(1,2,1,z)+h(2,0,0,z)-3*h(2,1,0,z)+2*h(2,1,1,z)+13*h(1,0,0,0,z)-4*h(1,1,0,0,z)+8*h(1,1,1,0,z)+2*h(2,z)*(zeta2)-22*h(0,z)*(zeta3)-h(1,z)*(zeta3)+3*h(4,z))+16*(17*(pow(z,2))-5)*h(0,0,0,0,z)-8*(59*(pow(z,2))+23)*(zeta4))+(32./9.)*z*h(1,1,z)-(4./81.)*(1./(1-z))*h(0,z)*(1127*(pow(z,2))-1628*z+1470)+(224./9.)*h(1,z)*(1-z)*(zeta2)-(104./27.)*h(1,z)*(z+2)+(1./81.)*(-3755*z-6511))+(pow(CF,3))*(964*(1-z)+(1./3.)*(250*(pow(z,2))-648*z+471)*(1./(1-z))*h(0,z)-(2./3.)*(1245*z-1204)*h(1,z)-(32./3.)*(10*z-7)*h(-2,z)*(zeta2)+64*z*h(-3,0,z)-64*h(-2,2,z)+(8./3.)*(4*(pow(z,2))+z+2)*((z+1)/(z))*h(-1,0,z)+(1./3.)*(1./(1-z))*(-2*(840*(pow(z,2))-624*z-199)*h(2,z)-2*(16*(pow(z,3))-502*(pow(z,2))-36*z+553)*(zeta2)+8*(4*(pow(z,3))-95*(pow(z,2))+93*z-27)*h(0,0,z)-16*(34*(pow(z,2))-67*z+39)*h(1,0,z))-(8./3.)*(7*z-13)*h(1,1,z)-(64./3.)*(10*z-1)*h(-2,-1,0,z)-(16./3.)*(z+1)*(-39*h(-1,z)*(zeta2)+16*h(-1,2,z)-46*h(-1,-1,0,z)+53*h(-1,0,0,z))-(32./3.)*(19*z-17)*h(1,-2,0,z)+(1./3.)*(1./(1-z))*(8*(89*(pow(z,2))-130*z+29)*h(3,z)+8*((pow(z,2))+66*z-29)*h(0,z)*(zeta2)+4*(97*(pow(z,2))-128*z+23)*h(1,z)*(zeta2)-4*(193*(pow(z,2))-176*z-83)*(zeta3)+8*(91*(pow(z,2))-98*z-3)*h(-2,0,z)-24*(7*(pow(z,2))-24*z+1)*h(2,0,z)-4*(161*(pow(z,2))-264*z+95)*h(1,2,z)-4*(51*(pow(z,2))-60*z+5)*h(2,1,z)-4*(119*(pow(z,2))-126*z+36)*h(0,0,0,z)-4*(91*(pow(z,2))-314*z+91)*h(1,0,0,z))+(4./3.)*(133*z-173)*h(1,1,0,z)+(8./3.)*(15*z-13)*h(1,1,2,z)+(32./3.)*(z-2)*h(1,2,1,z)+(1./3.)*(1./((1-z)*(z+1)))*(8*(2*(pow(z,3))-38*(pow(z,2))+7*z+23)*h(2,z)*(zeta2)+8*(22*(pow(z,3))-6*(pow(z,2))-31*z+9)*h(0,0,z)*(zeta2)-8*(38*(pow(z,3))+2*(pow(z,2))+z+61)*h(0,z)*(zeta3)+2*(118*(pow(z,3))-62*(pow(z,2))-523*z-367)*(zeta4)+8*(58*(pow(z,3))-12*(pow(z,2))-73*z+9)*h(3,0,z)+24*(35*(pow(z,3))+13*(pow(z,2))-23*z+7)*h(2,0,0,z)+8*(53*(pow(z,3))-23*(pow(z,2))-77*z-25)*h(2,1,0,z))-(32./3.)*(z+1)*(-5*h(-1,z)*(zeta3)+6*(zeta2)*h(-1,-1,z)-(zeta2)*h(-1,0,z)+2*h(-1,3,z)-4*h(-1,-1,2,z)+4*h(-1,-1,-1,0,z)+6*h(-1,0,0,0,z))+8*(z+1)*(-h(-1,z)*(zeta4)-4*(zeta3)*h(-1,0,z)-4*(zeta2)*h(-1,2,z)+2*(zeta2)*h(-1,0,0,z)+2*h(-1,3,0,z)+4*h(-1,2,0,0,z)-4*h(-1,2,1,0,z))+(1./3.)*(1./(1-z))*(-8*(17*(pow(z,2))-26*z-3)*h(4,z)-16*(15*(pow(z,2))+28*z+11)*h(1,z)*(zeta3)-48*(4*(pow(z,2))-2*z+5)*(zeta2)*h(1,0,z)+8*(93*(pow(z,2))-164*z+95)*h(1,3,z)+24*(7*(pow(z,2))-2*z-6)*h(2,2,z)+8*(25*(pow(z,2))-22*z+3)*h(3,1,z)-32*(21*(pow(z,2))-26*z+11)*h(-2,0,0,z)+16*(2*(pow(z,2))-26*z+3)*h(1,2,0,z)-12*(5*(pow(z,2))-10*z-1)*h(0,0,0,0,z)-16*(13*(pow(z,2))-50*z+10)*h(1,0,0,0,z))-(8./3.)*(35*z-29)*h(1,1,0,0,z)+(8./3.)*(11*z-9)*h(1,1,1,0,z)+(1./3.)*(1./(1-z))*(256*h(-4,0,z)*(pow(z,2))-16*(7*(pow(z,2))+5)*h(5,z)+16*(19*(pow(z,2))-5)*h(2,z)*(zeta3)+16*(47*(pow(z,2))+41)*(zeta2)*(zeta3)-4*(17*(pow(z,2))+139)*h(0,z)*(zeta4)-8*(355*(pow(z,2))+381)*(zeta5)+48*(3*z-1)*(3*z+1)*(zeta3)*h(0,0,z)+16*(5*(pow(z,2))-13)*(zeta2)*h(2,0,z)+16*((pow(z,2))-5)*(zeta2)*h(2,1,z)+16*(17*(pow(z,2))+23)*h(2,3,z)+32*(9*(pow(z,2))+5)*h(3,2,z)+128*(2*(pow(z,2))+1)*h(4,0,z)+32*(5*(pow(z,2))+1)*h(-3,0,0,z)+32*(13*(pow(z,2))+7)*h(2,1,2,z)+32*(23*(pow(z,2))+15)*h(2,2,0,z)+32*(10*(pow(z,2))+9)*h(3,0,0,z)+96*(3*(pow(z,2))+2)*h(3,1,0,z)-96*(2*(pow(z,2))-1)*h(2,0,0,0,z)+32*(19*(pow(z,2))+9)*h(2,1,0,0,z)+16*(3*(pow(z,2))+1)*(-2*h(3,z)*(zeta2)+h(4,1,z)+9*h(2,1,1,0,z))-8*((pow(z,2))+1)*(14*h(-3,z)*(zeta2)+24*h(-2,-1,z)*(zeta2)-4*h(-2,0,z)*(zeta2)-20*h(1,-2,z)*(zeta2)-18*h(1,2,z)*(zeta2)-8*h(0,0,0,z)*(zeta2)+16*h(1,1,0,z)*(zeta2)-20*h(-2,z)*(zeta3)+9*h(1,z)*(zeta4)+28*h(-3,2,z)+8*h(-2,3,z)-68*(zeta3)*h(1,0,z)-36*(zeta3)*h(1,1,z)+84*h(-3,-1,0,z)-16*h(-2,-1,2,z)+8*h(1,-3,0,z)+24*h(1,-2,2,z)-96*h(1,1,3,z)-42*h(1,2,2,z)-76*h(1,3,0,z)-52*h(1,3,1,z)+32*h(2,-2,0,z)-32*h(2,2,1,z)-24*h(3,1,1,z)+16*h(-2,-1,-1,0,z)+24*h(-2,0,0,0,z)+8*h(1,-2,-1,0,z)+56*h(1,-2,0,0,z)-40*h(1,1,-2,0,z)-60*h(1,1,2,0,z)-68*h(1,2,0,0,z)-52*h(1,2,1,0,z)-12*h(0,0,0,0,0,z)+56*h(1,1,0,0,0,z)-48*h(1,1,1,0,0,z))))+(pow(CA,2))*(CF)*(((1136639*z-542581)/1458.)+(2./81.)*(12863*(pow(z,2))-12422*z-15080)*(1./(1-z))*h(0,z)-(2./27.)*(5369*z-4526)*h(1,z)+(80./3.)*(z+2)*h(-2,z)*(zeta2)-(2./9.)*(579*z-431)*h(1,z)*(zeta2)-(32./3.)*(7*z+4)*h(-2,2,z)+(4./3.)*(6*(pow(z,2))+64*z+3)*((z+1)/(z))*h(-1,0,z)+(1./81.)*(1./(1-z))*(-6*(2512*(pow(z,2))-909*z-1492)*h(2,z)-2*(324*(pow(z,3))-8471*(pow(z,2))+4821*z+3605)*(zeta2)+6*(108*(pow(z,3))-6333*(pow(z,2))+5026*z-2974)*h(0,0,z)+18*(185*(pow(z,2))-339*z+86)*h(1,0,z))+(52./3.)*z*h(1,1,z)+(4./9.)*(11*z+14)*h(2,1,z)-(32./3.)*(9*z-2)*h(-2,-1,0,z)-(160./3.)*(1-z)*h(-2,0,0,z)-(8./3.)*(z+1)*(-36*h(-1,z)*(zeta2)+14*h(-1,2,z)-44*h(-1,-1,0,z)+45*h(-1,0,0,z))+(1./27.)*(1./(1-z))*(-2*(281*(pow(z,2))+492*z-100)*h(3,z)+2*(1225*(pow(z,2))-264*z+448)*h(0,z)*(zeta2)+2*(2598*(pow(z,2))-4506*z-2183)*(zeta3)+36*(127*(pow(z,2))-136*z+27)*h(-2,0,z)-6*(651*(pow(z,2))-642*z+527)*h(1,2,z)-6*(623*(pow(z,2))-406*z+232)*h(2,0,z)-30*(149*(pow(z,2))-64*z+103)*h(0,0,0,z)-12*(340*(pow(z,2))-847*z+349)*h(1,0,0,z)-6*(245*(pow(z,2))-18*z+309)*h(1,1,0,z))+(1./9.)*(1./((1-z)*(z+1)))*(8*(17*(pow(z,3))-28*(pow(z,2))+23*z+50)*h(2,z)*(zeta2)+4*(28*(pow(z,3))-23*(pow(z,2))+37*z+106)*h(0,0,z)*(zeta2)-4*(98*(pow(z,3))+59*(pow(z,2))-202*z-127)*h(0,z)*(zeta3)-3*(115*(pow(z,3))+680*(pow(z,2))+313*z-240)*(zeta4)-12*(10*(pow(z,3))+54*(pow(z,2))+65*z+15)*h(3,0,z)+4*(115*(pow(z,3))+124*(pow(z,2))-110*z-83)*h(2,0,0,z)-4*(4*(pow(z,3))+31*(pow(z,2))+76*z+85)*h(2,1,0,z))-(32./3.)*(z+1)*(-6*h(-1,z)*(zeta3)+(15./2.)*(zeta2)*h(-1,-1,z)-3*(zeta2)*h(-1,0,z)+3*h(-1,3,z)+2*h(-1,-2,0,z)-7*h(-1,-1,2,z)-2*h(-1,2,0,z)-h(-1,2,1,z)+h(-1,-1,-1,0,z)-2*h(-1,-1,0,0,z)+4*h(-1,0,0,0,z))+2*(z+1)*(-h(-1,z)*(zeta4)-4*(zeta3)*h(-1,0,z)-4*(zeta2)*h(-1,2,z)+2*(zeta2)*h(-1,0,0,z)+2*h(-1,3,0,z)+4*h(-1,2,0,0,z)-4*h(-1,2,1,0,z))+(1./9.)*(1./(1-z))*(-4*(59*(pow(z,2))-39*z+68)*h(4,z)+4*(145*(pow(z,2))-330*z+133)*h(1,z)*(zeta3)-24*(18*(pow(z,2))-25*z-8)*h(-3,0,z)-4*(13*(pow(z,2))-66*z+43)*(zeta2)*h(1,0,z)+8*(40*(pow(z,2))-27*z+31)*(zeta2)*h(1,1,z)+12*(31*(pow(z,2))-113*z+40)*h(1,3,z)-8*(49*(pow(z,2))-45*z+49)*h(2,2,z)+4*(56*(pow(z,2))-39*z+23)*h(3,1,z)+48*(2*z-1)*(11*z-14)*h(1,-2,0,z)-4*((pow(z,2))-75*z-14)*h(1,1,2,z)-24*(9*(pow(z,2))+3*z+2)*h(1,2,0,z)+12*(14*(pow(z,2))-z+9)*h(1,2,1,z)-4*(67*(pow(z,2))+72*z+64)*h(0,0,0,0,z)+4*(19*(pow(z,2))+84*z+37)*h(1,0,0,0,z)-4*(109*(pow(z,2))-120*z+121)*h(1,1,0,0,z)+352*((pow(z,2))+1)*h(1,1,1,0,z))+(1./3.)*(1./(1-z))*(64*(zeta2)*h(2,1,z)*(pow(z,2))-16*((pow(z,2))+5)*h(5,z)+8*(17*(pow(z,2))+21)*h(3,z)*(zeta2)-20*(11*(pow(z,2))+13)*h(2,z)*(zeta3)+4*(49*(pow(z,2))+95)*(zeta2)*(zeta3)-4*(31*(pow(z,2))+42)*h(0,z)*(zeta4)-4*(75*(pow(z,2))-1)*(zeta5)-32*((pow(z,2))+2)*h(-4,0,z)-4*(37*(pow(z,2))+11)*(zeta3)*h(0,0,z)+4*(35*(pow(z,2))+9)*(zeta2)*h(2,0,z)-4*(31*(pow(z,2))+13)*h(2,3,z)+4*((pow(z,2))+7)*h(4,1,z)-16*(5*(pow(z,2))+7)*h(-3,0,0,z)-16*(7*(pow(z,2))+9)*h(2,-2,0,z)+4*((pow(z,2))-17)*(h(2,1,2,z)-(zeta2)*h(0,0,0,z))+16*(2*(pow(z,2))+1)*h(2,2,0,z)+4*(15*(pow(z,2))+13)*h(3,0,0,z)+4*(33*(pow(z,2))+35)*h(2,0,0,0,z)+4*(49*(pow(z,2))+31)*h(2,1,0,0,z)+4*(13*(pow(z,2))-17)*h(2,1,1,0,z)+12*(5*(pow(z,2))+3)*h(0,0,0,0,0,z)-4*((pow(z,2))+1)*(-40*h(-3,z)*(zeta2)+60*h(-2,-1,z)*(zeta2)-24*h(-2,0,z)*(zeta2)-20*h(1,-2,z)*(zeta2)-40*h(1,2,z)*(zeta2)+2*h(1,0,0,z)*(zeta2)-12*h(1,1,0,z)*(zeta2)-16*h(1,1,1,z)*(zeta2)-48*h(-2,z)*(zeta3)+21*h(1,z)*(zeta4)+64*h(-3,2,z)+24*h(-2,3,z)+38*(zeta3)*h(1,0,z)-12*(zeta3)*h(1,1,z)+6*h(1,4,z)+12*h(3,2,z)-12*h(4,0,z)+48*h(-3,-1,0,z)+16*h(-2,-2,0,z)-56*h(-2,-1,2,z)-16*h(-2,2,0,z)-8*h(-2,2,1,z)+72*h(1,-3,0,z)+8*h(1,-2,2,z)-32*h(1,1,3,z)+16*h(1,2,2,z)-44*h(1,3,0,z)-16*h(1,3,1,z)+2*h(2,2,1,z)+6*h(3,1,0,z)+8*h(-2,-1,-1,0,z)-16*h(-2,-1,0,0,z)+32*h(-2,0,0,0,z)-24*h(1,-2,-1,0,z)+64*h(1,-2,0,0,z)-40*h(1,1,-2,0,z)+16*h(1,1,1,2,z)-12*h(1,1,2,0,z)+8*h(1,1,2,1,z)-30*h(1,2,0,0,z)+2*h(1,2,1,0,z)-32*h(1,0,0,0,0,z)-28*h(1,1,0,0,0,z)-16*h(1,1,1,0,0,z))))+(CA)*(pow(CF,2))*(((23060*(1-z))/81.)+(1./81.)*(-76790*(pow(z,2))+68912*z+30003)*(1./(1-z))*h(0,z)+(4./27.)*(7333*z-6709)*h(1,z)-144*h(-2,z)*(zeta2)+(32./3.)*(14*z+11)*h(-2,2,z)-(4./3.)*(z+8)*(16*z+1)*((z+1)/(z))*h(-1,0,z)+(1./81.)*(1./(1-z))*(2*(23474*(pow(z,2))-13731*z-15685)*h(2,z)+18*(96*(pow(z,3))-2229*(pow(z,2))+841*z+1450)*(zeta2)-2*(864*(pow(z,3))-29056*(pow(z,2))+29454*z-12035)*h(0,0,z)-2*(1069*(pow(z,2))+4155*z-704)*h(1,0,z))-(4./9.)*(91*z-15)*h(1,1,z)+(32./3.)*(28*z-5)*h(-2,-1,0,z)+(8./3.)*(z+1)*(-111*h(-1,z)*(zeta2)+44*h(-1,2,z)-134*h(-1,-1,0,z)+143*h(-1,0,0,z))+(1./27.)*(1./(1-z))*(-2*(1217*(pow(z,2))-3354*z+1382)*h(3,z)-2*(2291*(pow(z,2))+690*z-286)*h(0,z)*(zeta2)-6*(1295*(pow(z,2))-2014*z+671)*h(1,z)*(zeta2)+2*(4376*(pow(z,2))+6378*z-3193)*(zeta3)-36*(345*(pow(z,2))-370*z+51)*h(-2,0,z)+6*(1631*(pow(z,2))-1686*z+1079)*h(1,2,z)+2*(4387*(pow(z,2))-4554*z+1348)*h(2,0,z)+12*(225*(pow(z,2))-137*z+168)*h(2,1,z)+2*(3305*(pow(z,2))-3024*z+2081)*h(0,0,0,z)+4*(1810*(pow(z,2))-6279*z+1837)*h(1,0,0,z)+6*(873*(pow(z,2))-1010*z+1209)*h(1,1,0,z))+(1./9.)*(1./((1-z)*(z+1)))*(-4*(143*(pow(z,3))-235*(pow(z,2))+35*z+269)*h(2,z)*(zeta2)-16*(22*(pow(z,3))-35*(pow(z,2))-35*z+40)*h(0,0,z)*(zeta2)+4*(733*(pow(z,3))+355*(pow(z,2))-479*z+43)*h(0,z)*(zeta3)+(761*(pow(z,3))+4331*(pow(z,2))+3482*z+56)*(zeta4)-4*(167*(pow(z,3))-307*(pow(z,2))-628*z-82)*h(3,0,z)-4*(568*(pow(z,3))+406*(pow(z,2))-389*z-83)*h(2,0,0,z)-12*(56*(pow(z,3))-32*(pow(z,2))-139*z-99)*h(2,1,0,z))+(16./3.)*(z+1)*(-29*h(-1,z)*(zeta3)+36*(zeta2)*h(-1,-1,z)-13*(zeta2)*h(-1,0,z)+14*h(-1,3,z)+8*h(-1,-2,0,z)-32*h(-1,-1,2,z)-8*h(-1,2,0,z)-4*h(-1,2,1,z)+8*h(-1,-1,-1,0,z)-8*h(-1,-1,0,0,z)+22*h(-1,0,0,0,z))+(8./3.)*(z+1)*(16*h(5,z)+3*h(-1,z)*(zeta4)+12*(zeta3)*h(-1,0,z)+12*(zeta2)*h(-1,2,z)+4*h(3,2,z)-6*(zeta2)*h(-1,0,0,z)-6*h(-1,3,0,z)-12*h(-1,2,0,0,z)+12*h(-1,2,1,0,z))+(1./9.)*(1./(1-z))*(12*(45*(pow(z,2))-66*z+16)*h(4,z)-4*(239*(pow(z,2))-1008*z+239)*h(1,z)*(zeta3)+48*(24*(pow(z,2))-31*z-8)*h(-3,0,z)+24*(17*(pow(z,2))-19*z+28)*(zeta2)*h(1,0,z)-16*(29*(pow(z,2))-9*z+20)*(zeta2)*h(1,1,z)-4*(469*(pow(z,2))-1116*z+517)*h(1,3,z)+8*(101*(pow(z,2))-120*z+125)*h(2,2,z)-16*(25*(pow(z,2))-18*z-2)*h(3,1,z)+48*(41*(pow(z,2))-66*z+31)*h(-2,0,0,z)-144*(21*(pow(z,2))-38*z+15)*h(1,-2,0,z)+12*((pow(z,2))-54*z-11)*h(1,1,2,z)+4*(161*(pow(z,2))+96*z+71)*h(1,2,0,z)-4*(91*(pow(z,2))-12*z+61)*h(1,2,1,z)-176*((pow(z,2))+1)*h(2,1,1,z)-4*(157*(pow(z,2))-162*z-52)*h(0,0,0,0,z)-8*(8*(pow(z,2))+288*z+35)*h(1,0,0,0,z)+8*(47*(pow(z,2))-3*z+62)*h(1,1,0,0,z)-8*(73*(pow(z,2))+33*z+70)*h(1,1,1,0,z))+(1./3.)*(1./(1-z))*(-48*(5*(pow(z,2))+7)*h(3,z)*(zeta2)-24*(45*(pow(z,2))+43)*(zeta3)*(zeta2)-8*(23*(pow(z,2))-17)*h(2,0,z)*(zeta2)-16*(7*(pow(z,2))-1)*h(2,1,z)*(zeta2)+8*(79*(pow(z,2))+107)*h(2,z)*(zeta3)+4*(153*(pow(z,2))+181)*h(0,z)*(zeta4)+8*(289*(pow(z,2))+325)*(zeta5)-64*((pow(z,2))-2)*h(-4,0,z)+16*(29*(pow(z,2))+15)*(zeta3)*h(0,0,z)-8*(3*(pow(z,2))+23)*h(2,3,z)-16*(17*(pow(z,2))+11)*h(4,0,z)+16*(5*(pow(z,2))+13)*h(-3,0,0,z)+32*(2*(pow(z,2))-1)*(h(4,1,z)+3*(zeta2)*h(0,0,0,z))+32*(11*(pow(z,2))+13)*h(2,-2,0,z)-48*(5*(pow(z,2))-1)*h(2,1,2,z)-8*(45*(pow(z,2))+29)*h(2,2,0,z)-8*(43*(pow(z,2))+35)*h(3,0,0,z)-8*(27*(pow(z,2))+47)*h(2,0,0,0,z)-352*(2*(pow(z,2))+1)*h(2,1,0,0,z)-8*(35*(pow(z,2))-13)*h(2,1,1,0,z)-8*(7*(pow(z,2))+3)*(h(3,1,0,z)+6*h(0,0,0,0,0,z))+8*((pow(z,2))+1)*(-33*h(-3,z)*(zeta2)+72*h(-2,-1,z)*(zeta2)-26*h(-2,0,z)*(zeta2)-30*h(1,-2,z)*(zeta2)-50*h(1,2,z)*(zeta2)+19*h(1,0,0,z)*(zeta2)+10*h(1,1,0,z)*(zeta2)-8*h(1,1,1,z)*(zeta2)-58*h(-2,z)*(zeta3)+((111*h(1,z)*(zeta4))/2.)+78*h(-3,2,z)+28*h(-2,3,z)+39*(zeta3)*h(1,0,z)-12*(zeta3)*h(1,1,z)-11*h(1,4,z)+90*h(-3,-1,0,z)+16*h(-2,-2,0,z)-64*h(-2,-1,2,z)-16*h(-2,2,0,z)-8*h(-2,2,1,z)+76*h(1,-3,0,z)+20*h(1,-2,2,z)-94*h(1,1,3,z)-4*h(1,2,2,z)-88*h(1,3,0,z)-36*h(1,3,1,z)-7*h(2,2,1,z)+16*h(-2,-1,-1,0,z)-16*h(-2,-1,0,0,z)+44*h(-2,0,0,0,z)-20*h(1,-2,-1,0,z)+92*h(1,-2,0,0,z)-60*h(1,1,-2,0,z)+8*h(1,1,1,2,z)-36*h(1,1,2,0,z)+4*h(1,1,2,1,z)-67*h(1,2,0,0,z)-21*h(1,2,1,0,z)-50*h(1,0,0,0,0,z)-44*h(1,1,1,0,0,z))));
}

double ifunc::I3qqp(double z)
{
  return Istqqp(z)+((((pow(NC,2))-1)*((pow(NC,2))-4)/(NC)*(TF))/(16*(NC)*((pow(NC,2))-1)))*Id33(z);
}

double ifunc::I3qqbp(double z)
{
  return Istqqp(z)-((((pow(NC,2))-1)*((pow(NC,2))-4)/(NC)*(TF))/(16*(NC)*((pow(NC,2))-1)))*Id33(z);
}

double ifunc::I3qq(double z)
{
  return Istqq(z)+I3qqp(z);
}

double ifunc::I3qqb(double z)
{
  return (CF)*((CA)-2*(CF))*Istqqb(z)+I3qqbp(z);
}

double ifunc::I3qg(double z)
{
  return (CA)*(NF)*(pow(TF,2))*((1./81.)*(1./(z))*(-24*(154*(pow(z,3))-123*(pow(z,2))+3*z-40)*h(1,0,z)-8*(435*(pow(z,3))-172*(pow(z,2))-18*z-120)*(zeta2))+(1./27.)*(1./(z))*(-16*(116*(pow(z,3))-128*(pow(z,2))+31*z-24)*h(1,0,0,z)+32*(26*(pow(z,3))-29*(pow(z,2))+4*z-6)*h(1,1,0,z)+16*h(1,z)*(82*(pow(z,3))-88*(pow(z,2))+23*z-12)*(zeta2)+48*(30*(pow(z,3))+7*(pow(z,2))+18*z-4)*(zeta3))+(80./9.)*(2*(pow(z,2))+2*z+1)*(2*h(-1,-1,0,z)+h(-1,z)*(zeta2))-(32./9.)*(2*(pow(z,2))+2*z+1)*((3./2.)*(zeta2)*h(-1,-1,z)-(3./2.)*(zeta2)*h(-1,0,z)+3*h(-3,0,z)-3*h(-2,-1,0,z)+(9./2.)*h(-2,0,0,z)-3*h(-1,-2,0,z)+3*h(-1,-1,-1,0,z)-(9./2.)*h(-1,-1,0,0,z)+4*h(-1,0,0,0,z)-(3./2.)*h(-2,z)*(zeta2)-(3./2.)*h(-1,z)*(zeta3))-(16./9.)*(2*(pow(z,2))-2*z+1)*((zeta2)*h(1,0,z)+2*(zeta2)*h(1,1,z)+2*h(1,3,z)-8*h(1,1,2,z)-2*h(1,2,0,z)-5*h(1,2,1,z)-3*h(1,0,0,0,z)+4*h(1,1,0,0,z)-4*h(1,1,1,0,z)+5*h(1,1,1,1,z)-10*h(1,z)*(zeta3))-(16./9.)*(20*(pow(z,2))+21*z+10)*h(-2,0,z)-(8./81.)*(299*(pow(z,2))+290*z+85)*h(-1,0,z)-(8./81.)*(391*(pow(z,2))+1407*z+32)*h(0,0,z)-(8./81.)*(290*(pow(z,2))-326*z+85)*h(1,1,z)+(8./9.)*(8*(pow(z,2))+65*z+12)*h(2,0,z)-(16./27.)*(62*(pow(z,2))+62*z+25)*h(-1,0,0,z)+(32./27.)*(23*(pow(z,2))-74*z-4)*h(0,0,0,z)-(32./27.)*(23*(pow(z,2))-23*z+10)*(h(1,2,z)-h(1,1,1,z))+(16./3.)*(2*(pow(z,2))+6*z+1)*h(2,0,0,z)+(16./9.)*z*(12*h(3,0,z)-12*h(2,1,0,z)-12*h(2,z)*(zeta2)-19*(zeta4))-(8./9.)*z*(5*h(3,z)-2*h(2,1,z))-(32./9.)*(12*z-1)*h(0,0,0,0,z)+(8./243.)*(1./(z))*h(1,z)*(668*(pow(z,3))-1064*(pow(z,2))+103*z-36)+(8./9.)*h(0,z)*(8*(pow(z,2))+27*z+12)*(zeta2)+(8./243.)*(2280*(pow(z,2))-8119*z-523)*h(0,z)+(16./27.)*h(2,z)*(3*(pow(z,2))-23*z-3)+((4*(43324*(pow(z,3))-24198*(pow(z,2))-8697*z-1582))/(729*z)))+(CF)*(NF)*(pow(TF,2))*(-(32./9.)*((1-z)/(z))*(22*(pow(z,2))+13*z+4)*(h(1,1,0,z)+h(1,z)*(zeta2))+(1./81.)*(1./(z))*(32*(382*(pow(z,3))-403*(pow(z,2))+131*z-96)*h(1,0,z)+32*(253*(pow(z,3))-274*(pow(z,2))+89*z-96)*(zeta2))+(1./27.)*(1./(z))*(-16*(184*(pow(z,3))-28*(pow(z,2))-133*z-48)*h(1,0,0,z)-32*(100*(pow(z,3))-133*(pow(z,2))+77*z+12)*(zeta3))+(32./3.)*(4*(pow(z,2))+6*z+3)*((zeta2)*h(0,0,z)+h(3,0,z)+2*h(2,0,0,z)-h(2,1,0,z)-h(2,z)*(zeta2)+h(0,z)*(zeta3))-(4./81.)*(7424*(pow(z,2))+6559*z-6023)*h(0,0,z)+(8./81.)*(308*(pow(z,2))-353*z+112)*h(1,1,z)+(4./27.)*(1344*(pow(z,2))-1282*z+1805)*h(0,0,0,z)-(32./27.)*(23*(pow(z,2))-23*z+10)*(h(2,1,z)+h(1,1,1,z))-(16./9.)*(44*(pow(z,2))+94*z-47)*h(0,0,0,0,z)+(80./9.)*(2*(pow(z,2))-2*z+1)*(h(2,1,1,z)+2*h(1,0,0,0,z)+h(1,1,1,1,z))-(32./9.)*z*(10*z-9)*(h(2,0,z)+h(0,z)*(zeta2))-64*(2*z-1)*h(0,0,0,0,0,z)+(8./243.)*h(0,z)*(17172*(pow(z,2))+7693*z+20752)+(8./243.)*h(1,z)*(268*(pow(z,2))+155*z-355)+(224./81.)*(11*(pow(z,2))-11*z+4)*h(2,z)-(8./9.)*(104*(pow(z,2))+106*z+73)*(zeta4)-((441320*(pow(z,3))+989034*(pow(z,2))-1294539*z-160736)/(1458*z)))+(1./3.)*(pow(CF,2))*(TF)*((1./8.)*(-5020*(pow(z,2))+2406*z+2127)+(-708*(pow(z,2))-734*z+235)*h(0,z)-2*(354*(pow(z,2))+191*z-505)*h(1,z)-4*(151*(pow(z,2))-343*z-70)*h(2,z)+4*(24*(pow(z,2))-11*z+49)*h(3,z)-4*(50*(pow(z,2))-136*z+5)*h(4,z)+8*(194*(pow(z,2))+18*z-35)*(zeta2)+4*(57*(pow(z,2))-33*z-49)*h(0,z)*(zeta2)-8*(3*(pow(z,2))-9*z-10)*h(1,z)*(zeta2)-16*(5*(pow(z,2))+2*z-2)*h(2,z)*(zeta2)+64*(7*(pow(z,2))+2*z+1)*h(3,z)*(zeta2)+4*(757*(pow(z,2))-758*z+317)*(zeta3)-96*(z+1)*(2*z+1)*h(-1,z)*(zeta3)+4*(398*(pow(z,2))-344*z+57)*h(0,z)*(zeta3)-8*(1-z)*(175*z-73)*h(1,z)*(zeta3)+32*(39*(pow(z,2))-34*z+20)*h(2,z)*(zeta3)-64*(23*(pow(z,2))-5*z+11)*(zeta2)*(zeta3)+2*(227*(pow(z,2))+416*z+344)*(zeta4)+4*(348*(pow(z,2))-118*z+109)*h(0,z)*(zeta4)-8*(84*(pow(z,2))-454*z+63)*(zeta5)+64*(16*(pow(z,2))+7)*h(-4,0,z)+16*(53*(pow(z,2))+46*z+47)*h(-3,0,z)+8*(63*(pow(z,2))+98*z+135)*h(-2,0,z)-64*z*(3*z+2)*(zeta2)*h(-2,0,z)+4*(251*(pow(z,2))+634*z+395)*h(-1,0,z)-8*(21*(pow(z,2))+2*z-13)*(zeta2)*h(-1,0,z)+(-1012*(pow(z,2))-857*z+15)*h(0,0,z)+4*(158*(pow(z,2))-168*z+5)*(zeta2)*h(0,0,z)-4*(2*(pow(z,2))-26*z+77)*h(1,0,z)+16*(29*(pow(z,2))-35*z+15)*(zeta2)*h(1,0,z)-2*(302*(pow(z,2))-353*z+110)*h(1,1,z)-8*(10*(pow(z,2))-18*z+17)*(zeta2)*h(1,1,z)+16*(6*(pow(z,2))-9*z+2)*h(1,2,z)-8*(25*(pow(z,2))-12*z-7)*h(1,3,z)-4*(4*(pow(z,2))+108*z-7)*h(2,0,z)+32*(9*(pow(z,2))-10*z+6)*(zeta2)*h(2,0,z)+4*(27*(pow(z,2))-47*z+35)*h(2,1,z)-16*(6*(pow(z,2))+6*z-1)*(zeta2)*h(2,1,z)+8*(13*(pow(z,2))+2)*h(2,2,z)-32*(3*(pow(z,2))-8*z+3)*h(2,3,z)+8*(33*(pow(z,2))-98*z+7)*h(3,0,z)-8*(6*(pow(z,2))-8*z-3)*h(3,1,z)+64*(3*(pow(z,2))-2*z+1)*h(3,2,z)-32*(10*(pow(z,2))+6*z+5)*(h(-3,z)*(zeta2)+2*h(-3,-1,0,z))+32*(26*(pow(z,2))+18*z+11)*h(-3,0,0,z)-64*(8*(pow(z,2))+4*z+3)*h(-2,-2,0,z)-8*(36*(pow(z,2))+38*z+21)*(h(-2,z)*(zeta2)+2*h(-2,-1,0,z))+8*(112*(pow(z,2))+138*z+55)*h(-2,0,0,z)-112*(z+1)*(7*z+3)*h(-1,-2,0,z)-4*(63*(pow(z,2))+96*z+41)*(h(-1,z)*(zeta2)+2*h(-1,-1,0,z))+4*(209*(pow(z,2))+384*z+183)*h(-1,0,0,z)+192*z*(z+1)*h(-1,2,0,z)+(-792*(pow(z,2))-694*z+65)*h(0,0,0,z)-8*(4*(pow(z,2))-2*z+1)*(13*h(5,z)-43*(zeta3)*h(0,0,z)+4*h(4,0,z)-4*h(4,1,z)-13*(zeta2)*h(0,0,0,z))+32*(2*(pow(z,2))-22*z+17)*h(1,-2,0,z)+4*(z+1)*(11*z-21)*h(1,0,0,z)-8*(2*(pow(z,2))-5*z-6)*h(1,1,0,z)+4*(27*(pow(z,2))-38*z+15)*h(1,1,1,z)+8*(13*(pow(z,2))-12*z+8)*h(1,1,2,z)+8*(57*(pow(z,2))-68*z+23)*h(1,2,0,z)-8*(6*(pow(z,2))-4*z-5)*h(1,2,1,z)+64*(2*(pow(z,2))+3)*h(2,-2,0,z)+16*(4*(pow(z,2))-35*z+2)*h(2,0,0,z)-8*(19*(pow(z,2))-13)*h(2,1,0,z)-4*(2*z-1)*(8*z+3)*h(2,1,1,z)+16*(2*(pow(z,2))-6*z+5)*h(2,1,2,z)+32*(17*(pow(z,2))-12*z+5)*h(2,2,0,z)+16*(16*(pow(z,2))-14*z+7)*h(2,2,1,z)-32*(16*(pow(z,2))+14*z+1)*h(3,0,0,z)+16*(48*(pow(z,2))-2*z+13)*h(3,1,0,z)+16*(28*(pow(z,2))-26*z+13)*h(3,1,1,z)+32*(8*(pow(z,2))+6*z+3)*(-h(-2,z)*(zeta3)+(zeta2)*h(-2,-1,z)+2*h(-2,-1,-1,0,z))-32*(24*(pow(z,2))+10*z+9)*h(-2,-1,0,0,z)+64*(3*(pow(z,2))+z+1)*h(-2,0,0,0,z)+96*(z+1)*(3*z+1)*((zeta2)*h(-1,-1,z)+2*h(-1,-1,-1,0,z))-64*(z+1)*(14*z+9)*h(-1,-1,0,0,z)+8*(61*(pow(z,2))+82*z+27)*h(-1,0,0,0,z)-8*(94*(pow(z,2))+21*z-4)*h(0,0,0,0,z)-8*(33*(pow(z,2))-56*z+17)*h(1,0,0,0,z)+8*(8*(pow(z,2))-50*z+45)*h(1,1,0,0,z)-8*(19*(pow(z,2))-42*z+26)*h(1,1,1,0,z)-4*(16*(pow(z,2))-20*z+1)*h(1,1,1,1,z)-16*(40*(pow(z,2))-26*z+11)*h(2,0,0,0,z)+32*(4*(pow(z,2))+2*z+1)*h(2,1,0,0,z)-16*(4*(pow(z,2))+14*z-5)*h(2,1,1,0,z)+8*(60*(pow(z,2))-62*z+31)*h(2,1,1,1,z)-16*(2*(pow(z,2))+2*z+1)*(22*h(-1,z)*(zeta4)-10*(zeta2)*h(-1,-2,z)-8*(zeta3)*h(-1,-1,z)+4*(zeta3)*h(-1,0,z)+12*(zeta2)*h(-1,2,z)+22*h(-1,-3,0,z)+8*(zeta2)*h(-1,-1,-1,z)-6*(zeta2)*h(-1,-1,0,z)-6*h(-1,3,0,z)-20*h(-1,-2,-1,0,z)+30*h(-1,-2,0,0,z)-16*h(-1,-1,-2,0,z)-22*h(-1,2,0,0,z)+12*h(-1,2,1,0,z)+16*h(-1,-1,-1,-1,0,z)-24*h(-1,-1,-1,0,0,z)+6*h(-1,-1,0,0,0,z)-5*h(-1,0,0,0,0,z))-16*(24*(pow(z,2))+4*z+3)*h(0,0,0,0,0,z)-16*(2*(pow(z,2))-2*z+1)*(-25*h(1,z)*(zeta4)-39*(zeta3)*h(1,0,z)-39*(zeta3)*h(1,1,z)-2*(zeta2)*h(1,2,z)+12*h(1,4,z)-10*h(1,-3,0,z)-12*(zeta2)*h(1,0,0,z)-8*(zeta2)*h(1,1,0,z)+3*(zeta2)*h(1,1,1,z)+2*h(1,1,3,z)-6*h(1,2,2,z)-2*h(1,3,0,z)-3*h(1,3,1,z)+4*h(1,-2,0,0,z)-4*h(1,1,-2,0,z)-h(1,1,1,2,z)-17*h(1,1,2,0,z)-7*h(1,1,2,1,z)-5*h(1,2,0,0,z)-13*h(1,2,1,0,z)-14*h(1,2,1,1,z)+7*h(1,0,0,0,0,z)+20*h(1,1,0,0,0,z)-3*h(1,1,1,0,0,z)+h(1,1,1,1,0,z)-15*h(1,1,1,1,1,z)))+(1./27.)*(pow(CA,2))*(TF)*(3*((z+1)/(z))*(12*(60*(pow(z,2))+9*z+8)*h(-1,3,z)-8*(112*(pow(z,2))+53*z+16)*h(-1,-1,2,z)-32*(17*(pow(z,2))+4*z+2)*h(-1,2,1,z))+72*(8*(pow(z,2))+74*z-41)*h(-4,0,z)+24*(817*(pow(z,2))+180*z+216)*h(-3,0,z)+72*(56*(pow(z,2))+46*z+29)*h(-3,2,z)-4*(2426*(pow(z,2))-30*z-213)*h(-2,0,z)+72*(96*(pow(z,2))+37*z+31)*h(-2,2,z)+36*(100*(pow(z,2))+110*z+49)*h(-2,3,z)+(2./3.)*(126201*(pow(z,2))+29235*z+20278)*h(0,0,z)-36*(28*(pow(z,2))+66*z+29)*h(2,3,z)+12*(317*(pow(z,2))-135*z+51)*h(3,1,z)-72*(20*(pow(z,2))+50*z+19)*h(3,2,z)+108*(8*(pow(z,2))-14*z-3)*h(4,1,z)-144*(10*(pow(z,2))+22*z+3)*h(-3,-1,0,z)+36*(52*(pow(z,2))+214*z-35)*h(-3,0,0,z)+72*(8*(pow(z,2))-26*z+13)*h(-2,-2,0,z)-72*(78*(pow(z,2))+37*z+14)*h(-2,-1,0,z)-72*(76*(pow(z,2))+66*z+39)*h(-2,-1,2,z)+12*(1522*(pow(z,2))+246*z+297)*h(-2,0,0,z)-72*(8*(pow(z,2))+18*z+3)*h(-2,2,0,z)+108*(4*(pow(z,2))+6*z+3)*h(-1,3,0,z)-4*(7385*(pow(z,2))-1712*z+1679)*h(0,0,0,z)+144*(8*(pow(z,2))+10*z+7)*h(2,-2,0,z)-36*(16*(pow(z,2))-62*z+9)*h(2,1,2,z)+72*(24*(pow(z,2))-62*z-1)*h(2,2,0,z)-72*(2*(pow(z,2))-26*z+1)*h(2,2,1,z)+72*(6*(pow(z,2))-100*z+17)*h(3,0,0,z)+36*(4*(pow(z,2))-86*z-25)*h(3,1,0,z)-5184*z*h(4,0,z)+504*(z+1)*h(-1,2,0,z)+144*(8*z+3)*h(3,1,1,z)+(1./9.)*(1./(z))*(-2*h(0,z)*(747175*(pow(z,3))+62809*(pow(z,2))+167620*z+17152)-2*h(1,z)*(30151*(pow(z,3))+24401*(pow(z,2))-50692*z-6528))+4*h(3,z)*(1460*(pow(z,2))-483*z-321)-24*h(4,z)*(137*(pow(z,2))-48*z+51)-36*h(5,z)*(72*(pow(z,2))-58*z+9)+((2*(2153647*(pow(z,3))-2175249*(pow(z,2))+450714*z-470494))/(27*z))-144*(33*(pow(z,2))+34*z+16)*h(-3,z)*(zeta2)-36*(270*(pow(z,2))+111*z+76)*h(-2,z)*(zeta2)+36*(20*(pow(z,2))+18*z-13)*h(3,z)*(zeta2)-36*(136*(pow(z,2))+242*z+93)*(zeta3)*(zeta2)+72*(70*(pow(z,2))+66*z+33)*h(-2,-1,z)*(zeta2)-72*(50*(pow(z,2))+90*z+17)*h(-2,0,z)*(zeta2)+36*(88*(pow(z,2))-2*z+47)*h(2,0,z)*(zeta2)+288*(8*(pow(z,2))-z+6)*h(2,1,z)*(zeta2)-108*(16*(pow(z,2))+14*z+7)*h(-1,0,0,z)*(zeta2)+324*(2*z-1)*(4*z-1)*h(0,0,0,z)*(zeta2)-144*(19*(pow(z,2))+22*z+8)*h(-2,z)*(zeta3)+108*(52*(pow(z,2))+30*z+27)*h(2,z)*(zeta3)-36*(163*(pow(z,2))+166*z+83)*h(-1,z)*(zeta4)+9*(136*(pow(z,2))-38*z-425)*h(0,z)*(zeta4)-36*(136*(pow(z,2))-1206*z+77)*(zeta5)-144*(25*(pow(z,2))+28*z+14)*(zeta3)*h(-1,0,z)-144*(41*z+27)*(zeta3)*h(0,0,z)+(1./3.)*(1./(z))*(-4*(98*(pow(z,3))-12231*(pow(z,2))-702*z-1256)*h(2,z)-2*(49619*(pow(z,3))-58657*(pow(z,2))+11376*z-12536)*(zeta2)+2*(23245*(pow(z,3))+33484*(pow(z,2))+17579*z+5436)*h(-1,0,z)-2*(43978*(pow(z,3))-43401*(pow(z,2))+9435*z-9490)*h(1,0,z)+2*(6748*(pow(z,3))-12541*(pow(z,2))+7796*z-918)*h(1,1,z))+(1./(z*(z+1)))*(2*(3233*(pow(z,4))+7511*(pow(z,3))+5946*(pow(z,2))+2238*z+624)*h(0,z)*(zeta2)-2*(8577*(pow(z,4))+1403*(pow(z,3))-6989*(pow(z,2))-1467*z-1544)*h(1,z)*(zeta2)-2*(509*(pow(z,4))-13207*(pow(z,3))-8142*(pow(z,2))+2178*z-3288)*(zeta3)+6*(2059*(pow(z,4))+2811*(pow(z,3))+1118*(pow(z,2))+556*z+208)*h(2,0,z)+4*(7486*(pow(z,4))+123*(pow(z,3))-6050*(pow(z,2))-235*z-1494)*h(1,0,0,z)-2*(8519*(pow(z,4))-1361*(pow(z,3))-6983*(pow(z,2))+805*z-1984)*h(1,1,0,z))+(1./(z))*(4*(851*(pow(z,3))+1062*(pow(z,2))+246*z+272)*h(-1,z)*(zeta2)-8*(422*(pow(z,3))+393*(pow(z,2))+96*z+116)*h(-1,2,z)-4*(92*(pow(z,3))-1678*(pow(z,2))+1463*z-208)*h(1,2,z)-4*(445*(pow(z,3))-861*(pow(z,2))-111*z-116)*h(2,1,z)+8*(7*(pow(z,3))+276*(pow(z,2))+54*z+40)*h(-1,-1,0,z)-4*(393*(pow(z,3))+431*(pow(z,2))+124*z+484)*h(-1,0,0,z)-4*(337*(pow(z,3))-194*(pow(z,2))+175*z+40)*h(1,1,1,z))+3*(1./(z*(pow(z+1,2))))*(12*(102*(pow(z,5))+456*(pow(z,4))+671*(pow(z,3))+398*(pow(z,2))+103*z+16)*h(2,z)*(zeta2)+4*(1757*(pow(z,5))+2308*(pow(z,4))-811*(pow(z,3))-1470*(pow(z,2))-42*z+48)*h(0,z)*(zeta3)+(5103*(pow(z,5))+22925*(pow(z,4))+31855*(pow(z,3))+17187*(pow(z,2))+5012*z+1840)*(zeta4)-4*(155*(pow(z,5))+1756*(pow(z,4))+3167*(pow(z,3))+1830*(pow(z,2))+426*z+144)*h(2,0,0,z))+3*(1./((pow(z+1,2))))*(4*(436*(pow(z,4))+473*(pow(z,3))-323*(pow(z,2))-321*z+30)*(zeta2)*h(0,0,z)+36*(19*(pow(z,4))-37*(pow(z,3))-138*(pow(z,2))-89*z-8)*h(3,0,z)+4*(436*(pow(z,4))+1133*(pow(z,3))+1024*(pow(z,2))+393*z+84)*h(2,1,0,z))-864*((pow(z,2))+1)*h(-2,-1,-1,0,z)-36*(80*(pow(z,2))+254*z+5)*h(-2,-1,0,0,z)+72*(10*(pow(z,2))+78*z-7)*h(-2,0,0,0,z)+216*(8*(pow(z,2))+10*z+5)*(h(-1,2,0,0,z)-(zeta2)*h(-1,2,z))+72*(4*(pow(z,2))-2*z-1)*h(-1,2,1,0,z)-24*(108*(pow(z,2))-345*z-55)*h(0,0,0,0,z)+3*(1./(z))*(-12*(58*(pow(z,3))+72*(pow(z,2))+33*z+8)*h(-1,z)*(zeta3)-4*(555*(pow(z,3))-307*(pow(z,2))+38*z-176)*h(1,z)*(zeta3)+4*(298*(pow(z,3))+414*(pow(z,2))+189*z+40)*(zeta2)*h(-1,-1,z)-4*(401*(pow(z,3))+264*(pow(z,2))-30*z+56)*(zeta2)*h(-1,0,z)-4*(287*(pow(z,3))-389*(pow(z,2))+97*z-96)*(zeta2)*h(1,0,z)-8*(112*(pow(z,3))-98*(pow(z,2))-5*z-20)*(zeta2)*h(1,1,z)+4*(624*(pow(z,3))-761*(pow(z,2))+217*z-112)*h(1,3,z)+12*(97*(pow(z,3))-172*(pow(z,2))-59*z-16)*h(2,2,z)-8*(205*(pow(z,3))+195*(pow(z,2))+39*z+16)*h(-1,-2,0,z)-16*(8*(pow(z,3))+69*(pow(z,2))-60*z-8)*h(1,-2,0,z)-4*(471*(pow(z,3))-539*(pow(z,2))+220*z-64)*h(1,1,2,z)+4*(457*(pow(z,3))-352*(pow(z,2))-25*z-48)*h(1,2,0,z)-4*(383*(pow(z,3))-404*(pow(z,2))+124*z-48)*h(1,2,1,z)-16*(53*(pow(z,3))+6*(pow(z,2))-2)*h(2,1,1,z)+8*(74*(pow(z,3))+84*(pow(z,2))+51*z+8)*h(-1,-1,-1,0,z)-12*(286*(pow(z,3))+245*(pow(z,2))+16*z+24)*h(-1,-1,0,0,z)+4*(647*(pow(z,3))+494*(pow(z,2))+z+48)*h(-1,0,0,0,z)-4*(233*(pow(z,3))-63*(pow(z,2))-147*z-8)*h(1,0,0,0,z)+4*(845*(pow(z,3))-685*(pow(z,2))-4*z-112)*h(1,1,0,0,z)-4*(734*(pow(z,3))-811*(pow(z,2))+233*z-112)*h(1,1,1,0,z)-4*(14*(pow(z,2))-61*z-8)*h(1,1,1,1,z))-36*(52*(pow(z,2))-118*z-11)*h(2,0,0,0,z)-36*(20*(pow(z,2))+198*z+43)*h(2,1,0,0,z)+36*(20*(pow(z,2))+94*z+27)*h(2,1,1,0,z)+144*(4*z+1)*h(2,1,1,1,z)+72*(2*(pow(z,2))+2*z+1)*(28*(zeta2)*h(-1,-2,z)+4*(zeta3)*h(-1,-1,z)+10*h(-1,4,z)-16*h(-2,2,1,z)-24*h(-1,-3,0,z)-24*h(-1,-2,2,z)-18*(zeta2)*h(-1,-1,-1,z)+18*(zeta2)*h(-1,-1,0,z)-11*h(-1,-1,3,z)+10*h(-1,2,2,z)-10*h(-1,3,1,z)+8*h(-1,-2,-1,0,z)-16*h(-1,-2,0,0,z)+2*h(-1,-1,-2,0,z)+18*h(-1,-1,-1,2,z)+16*h(-1,-1,2,1,z)+4*h(-1,2,1,1,z)+7*h(-1,-1,-1,0,0,z)-3*h(-1,-1,0,0,0,z)+13*h(-1,0,0,0,0,z))+432*(15*z-4)*h(0,0,0,0,0,z)-18*(2*(pow(z,2))-2*z+1)*(57*h(1,z)*(zeta4)-24*(zeta2)*h(1,-2,z)-120*(zeta3)*h(1,0,z)+172*(zeta3)*h(1,1,z)-4*(zeta2)*h(1,2,z)+4*h(1,4,z)-56*h(1,-3,0,z)+16*h(1,-2,2,z)-44*(zeta2)*h(1,0,0,z)+32*(zeta2)*h(1,1,0,z)+16*(zeta2)*h(1,1,1,z)-64*h(1,1,3,z)-28*h(1,2,2,z)-76*h(1,3,0,z)-20*h(1,3,1,z)-16*h(1,-2,-1,0,z)+140*h(1,1,1,2,z)-8*h(1,1,2,0,z)+80*h(1,1,2,1,z)-116*h(1,2,0,0,z)-4*h(1,2,1,0,z)+40*h(1,2,1,1,z)+44*h(1,0,0,0,0,z)+76*h(1,1,0,0,0,z)-52*h(1,1,1,0,0,z)+172*h(1,1,1,1,0,z)-120*h(1,1,1,1,1,z)))+(1./27.)*(CA)*(CF)*(TF)*(((920124*(pow(z,3))-57058*(pow(z,2))-834293*z-116208)/(72*z))+(1./9.)*(-26970*(pow(z,2))-32212*z-13165)*h(0,z)+(2./9.)*(48075*(pow(z,3))+15479*(pow(z,2))-60229*z-2285)*(1./(z))*h(1,z)-(8./3.)*(2672*(pow(z,2))+3701*z+2576)*h(2,z)+12*(179*(pow(z,2))-278*z+134)*h(3,z)-12*(631*(pow(z,2))+78*z-6)*h(4,z)+144*(8*(pow(z,2))+16*z+11)*h(5,z)-144*(28*(pow(z,2))-14*z+25)*h(-4,0,z)-72*(63*(pow(z,2))+84*z+139)*h(-3,0,z)+144*(44*(pow(z,2))+10*z+23)*h(-3,2,z)+36*(70*(pow(z,2))+194*z-339)*h(-2,0,z)+216*(16*(pow(z,2))+28*z+15)*h(-2,2,z)+144*(47*(pow(z,2))+30*z+23)*h(-2,3,z)+18*(125*(pow(z,2))-824*z-929)*h(-1,0,z)+72*(28*(pow(z,2))+82*z+55)*h(-1,2,z)+216*(z+1)*(13*z+10)*h(-1,3,z)+(1./3.)*(-47946*(pow(z,2))+26249*z+1745)*h(0,0,z)+4*(694*(pow(z,2))-881*z-2)*h(2,1,z)-72*(14*(pow(z,2))-7*z-18)*h(2,2,z)+144*(3*(pow(z,2))-40*z+9)*h(2,3,z)+12*(172*(pow(z,2))+186*z+3)*h(3,1,z)+144*(4*(pow(z,2))-14*z+1)*h(3,2,z)+576*(1-z)*h(4,0,z)+72*(4*(pow(z,2))-10*z-3)*h(4,1,z)-144*(10*(pow(z,2))-10*z+1)*h(-3,-1,0,z)+144*(25*(pow(z,2))+8*z+4)*h(-3,0,0,z)+144*(8*(pow(z,2))-22*z+3)*h(-2,-2,0,z)+216*((pow(z,2))+20*z+6)*h(-2,-1,0,z)-288*(33*(pow(z,2))+14*z+17)*h(-2,-1,2,z)-36*(45*(pow(z,2))+79)*h(-2,0,0,z)+144*(4*(pow(z,2))+22*z+3)*h(-2,2,0,z)+1152*z*h(-2,2,1,z)+72*(27*(pow(z,2))+92*z+53)*h(-1,-2,0,z)-72*(35*(pow(z,2))+64*z+36)*h(-1,-1,0,z)-432*(z+1)*(8*z+11)*h(-1,-1,2,z)+36*(27*(pow(z,2))-98*z-133)*h(-1,0,0,z)+72*(5*(pow(z,2))-18*z-14)*h(-1,2,0,z)+144*(z-7)*(z+1)*h(-1,2,1,z)-432*(3*(pow(z,2))+2*z+1)*h(-1,3,0,z)+(1836*(pow(z,2))+11222*z+299)*h(0,0,0,z)-288*(9*(pow(z,2))-34*z+22)*h(1,-2,0,z)+(1./(z))*(4*(349*(pow(z,3))-1290*(pow(z,2))+1056*z-16)*h(1,2,z)+8*(21*(pow(z,3))+74*(pow(z,2))+20*z+46)*h(1,1,1,z))-288*(2*(pow(z,2))-4*z+5)*h(2,-2,0,z)+12*(176*(pow(z,2))+128*z-37)*h(2,1,1,z)+72*(76*(pow(z,2))-34*z+35)*h(2,1,2,z)-288*(2*(pow(z,2))+7*z+1)*h(2,2,0,z)+72*(18*(pow(z,2))-46*z+11)*h(2,2,1,z)-72*(10*(pow(z,2))-22*z+17)*h(3,0,0,z)-144*(31*(pow(z,2))+4*z+9)*h(3,1,0,z)-288*(2*(pow(z,2))+3*z+2)*h(3,1,1,z)-72*(98*(pow(z,2))+10*z+47)*h(-3,z)*(zeta2)-108*(31*(pow(z,2))+36*z+24)*h(-2,z)*(zeta2)-36*(91*(pow(z,2))+228*z+146)*h(-1,z)*(zeta2)-432*(17*(pow(z,2))-10*z+5)*h(3,z)*(zeta2)+72*(128*(pow(z,2))-6*z+77)*(zeta3)*(zeta2)+216*(38*(pow(z,2))+18*z+21)*h(-2,-1,z)*(zeta2)-72*(102*(pow(z,2))+54*z+59)*h(-2,0,z)*(zeta2)+108*(31*(pow(z,2))+60*z+34)*h(-1,-1,z)*(zeta2)-36*(93*(pow(z,2))+254*z+143)*h(-1,0,z)*(zeta2)+432*(8*(pow(z,2))+6*z+3)*h(-1,2,z)*(zeta2)-72*(8*(pow(z,2))-86*z+25)*h(2,0,z)*(zeta2)-288*((pow(z,2))-11*z+6)*h(2,1,z)*(zeta2)-72*(52*(pow(z,2))+46*z+23)*h(-1,0,0,z)*(zeta2)-144*(8*(pow(z,2))+14*z+11)*h(0,0,0,z)*(zeta2)-144*(42*(pow(z,2))+18*z+23)*h(-2,z)*(zeta3)-72*(37*(pow(z,2))+66*z+32)*h(-1,z)*(zeta3)+72*(20*(pow(z,2))-38*z-31)*h(2,z)*(zeta3)+3*(-1601*(pow(z,5))-8772*(pow(z,4))-15458*(pow(z,3))-10812*(pow(z,2))-2351*z+192)*(1./(z*(pow(z+1,2))))*(zeta4)+18*(454*(pow(z,2))+442*z+221)*h(-1,z)*(zeta4)-18*(148*(pow(z,2))-130*z+167)*h(0,z)*(zeta4)+36*(304*(pow(z,2))-974*z-49)*(zeta5)-72*(70*(pow(z,2))+82*z+41)*(zeta3)*h(-1,0,z)+72*(4*(pow(z,2))-66*z-33)*(zeta3)*h(0,0,z)+(1./3.)*(1./(z))*(2*(11111*(pow(z,3))-7057*(pow(z,2))+12248*z-1296)*(zeta2)-2*(6190*(pow(z,3))-5051*(pow(z,2))-1007*z-404)*h(1,0,z)+4*(564*(pow(z,3))+905*(pow(z,2))-1894*z+661)*h(1,1,z))+(1./(z+1))*(2*(2239*(pow(z,3))+1765*(pow(z,2))+180*z+708)*h(2,0,z)-6*(367*(pow(z,3))-1173*(pow(z,2))-1254*z+268)*h(0,z)*(zeta2))+(1./(z*(z+1)))*(-2*(59*(pow(z,4))-1351*(pow(z,3))+513*(pow(z,2))+1999*z-32)*h(1,z)*(zeta2)-2*(7677*(pow(z,4))-4303*(pow(z,3))-16010*(pow(z,2))-5458*z-1536)*(zeta3)-4*(710*(pow(z,4))-563*(pow(z,3))-575*(pow(z,2))+736*z+92)*h(1,0,0,z)+2*(2087*(pow(z,4))-763*(pow(z,3))-1863*(pow(z,2))+655*z-224)*h(1,1,0,z))+3*((1-z)/(z))*(4*(7*(pow(z,2))+49*z+16)*(zeta2)*h(1,1,z)-96*(17*(pow(z,2))+2)*h(1,2,1,z))+3*(1./((pow(z+1,2))))*(12*(37*(pow(z,4))+36*(pow(z,3))-72*(pow(z,2))-104*z-39)*h(2,z)*(zeta2)+4*(388*(pow(z,4))+1034*(pow(z,3))+889*(pow(z,2))+228*z-6)*h(0,0,z)*(zeta2)+4*(1132*(pow(z,4))+3764*(pow(z,3))+4405*(pow(z,2))+2046*z+255)*h(0,z)*(zeta3)-4*(613*(pow(z,4))+494*(pow(z,3))-758*(pow(z,2))-546*z+84)*h(3,0,z)-12*(199*(pow(z,4))+282*(pow(z,3))+45*(pow(z,2))+40*z+72)*h(2,0,0,z)+12*(57*(pow(z,4))+76*(pow(z,3))-24*(pow(z,2))-48*z-11)*h(2,1,0,z))-144*(18*(pow(z,2))+2*z+5)*h(-2,-1,-1,0,z)-72*(64*(pow(z,2))+70*z+27)*h(-2,-1,0,0,z)+72*(90*(pow(z,2))+70*z+37)*h(-2,0,0,0,z)-216*((pow(z,2))+16*z+10)*h(-1,-1,-1,0,z)+36*(5*z+8)*(9*z+10)*h(-1,-1,0,0,z)-36*(13*(pow(z,2))-26*z-9)*h(-1,0,0,0,z)-288*(7*(pow(z,2))+4*z+2)*h(-1,2,0,0,z)+864*(5*(pow(z,2))+4*z+2)*h(-1,2,1,0,z)-12*(948*(pow(z,2))-230*z+121)*h(0,0,0,0,z)+3*(1./(z))*(-24*(88*(pow(z,3))-187*(pow(z,2))+97*z+8)*h(1,z)*(zeta3)-4*(617*(pow(z,3))-492*(pow(z,2))+159*z-32)*(zeta2)*h(1,0,z)+4*(329*(pow(z,3))-72*(pow(z,2))-81*z-32)*h(1,3,z)+8*(17*(pow(z,3))-87*(pow(z,2))+69*z-8)*h(1,1,2,z)-4*(173*(pow(z,3))-204*(pow(z,2))+114*z+16)*h(1,2,0,z)-4*(203*(pow(z,3))-340*(pow(z,2))+239*z+8)*h(1,0,0,0,z)-4*(373*(pow(z,3))-522*(pow(z,2))+174*z-16)*h(1,1,0,0,z)+4*(277*(pow(z,3))-552*(pow(z,2))+273*z-16)*h(1,1,1,0,z)+8*(24*(pow(z,3))-23*(pow(z,2))-29*z-4)*h(1,1,1,1,z))+144*(7*(pow(z,2))-24*z-2)*h(2,0,0,0,z)-144*(7*(pow(z,2))-14*z-3)*h(2,1,0,0,z)+144*(47*(pow(z,2))-14*z+10)*h(2,1,1,0,z)-216*(20*(pow(z,2))-18*z+11)*h(2,1,1,1,z)+72*(2*(pow(z,2))+2*z+1)*(48*(zeta2)*h(-1,-2,z)+44*(zeta3)*h(-1,-1,z)+20*h(-1,4,z)+32*h(-1,-3,0,z)-60*h(-1,-2,2,z)-62*(zeta2)*h(-1,-1,-1,z)+58*(zeta2)*h(-1,-1,0,z)-53*h(-1,-1,3,z)+10*h(-1,2,2,z)-6*h(-1,3,1,z)-24*h(-1,-2,-1,0,z)-22*h(-1,-2,0,0,z)-10*h(-1,-1,-2,0,z)+78*h(-1,-1,-1,2,z)-4*h(-1,-1,2,0,z)-4*h(-1,2,1,1,z)+32*h(-1,-1,-1,-1,0,z)+41*h(-1,-1,-1,0,0,z)-51*h(-1,-1,0,0,0,z)+15*h(-1,0,0,0,0,z))+288*(8*z+3)*h(0,0,0,0,0,z)+18*(2*(pow(z,2))-2*z+1)*(h(1,z)*(zeta4)-24*(zeta2)*h(1,-2,z)-80*(zeta3)*h(1,0,z)-20*(zeta3)*h(1,1,z)-68*(zeta2)*h(1,2,z)+44*h(1,4,z)-8*h(1,-3,0,z)-16*h(1,-2,2,z)-68*(zeta2)*h(1,0,0,z)-32*(zeta2)*h(1,1,0,z)+40*(zeta2)*h(1,1,1,z)+24*h(1,1,3,z)+44*h(1,2,2,z)-52*h(1,3,0,z)+52*h(1,3,1,z)-80*h(1,-2,-1,0,z)+48*h(1,-2,0,0,z)-32*h(1,1,-2,0,z)+132*h(1,1,1,2,z)-24*h(1,1,2,0,z)+24*h(1,1,2,1,z)-92*h(1,2,0,0,z)+12*h(1,2,1,0,z)-72*h(1,2,1,1,z)-36*h(1,0,0,0,0,z)+68*h(1,1,0,0,0,z)-28*h(1,1,1,0,0,z)+180*h(1,1,1,1,0,z)-240*h(1,1,1,1,1,z)));
}

#else
  void   ifunc::test() {};
  double ifunc::I1qq(double z) {return 0.;};
  double ifunc::I1qg(double z) {return 0.;};

  double ifunc::I2qqp(double z) {return 0.;};
  double ifunc::I2qqb(double z) {return 0.;};
  double ifunc::I2qq(double z) {return 0.;};
  double ifunc::I2qg(double z) {return 0.;};

  void   ifunc::I3(double z) {};

  double ifunc::i3qqp;
  double ifunc::i3qqbp;
  double ifunc::i3qq;
  double ifunc::i3qqb;
  double ifunc::i3qg;

  double ifunc::Id33(double z) {return 0.;};
  double ifunc::Istqqp(double z) {return 0.;};
  double ifunc::Istqqb(double z) {return 0.;};
  double ifunc::Istqq(double z) {return 0.;};
  double ifunc::I3qqp(double z) {return 0.;};
  double ifunc::I3qqbp(double z) {return 0.;};
  double ifunc::I3qq(double z) {return 0.;};
  double ifunc::I3qqb(double z) {return 0.;};
  double ifunc::I3qg(double z) {return 0.;};
#endif
